# delimit;
set more off;

log using ../logs/katrina_hmda.txt, text replace;


*************************************************************************;
* First determine lending shares in and out of New Orleans CSA and branch;
*  presence in New Orleans for all lending institutions;
*************************************************************************;

* create file that maps 1990 tract numbers to the 2000 New Orleans CSA;
insheet using ../raw_data/la_al_tract_msa_map_1990.csv;

replace tract = round(censustractbna*100);
gen tract_str = string(county, "%05.0f") + string(tract, "%06.0f");

keep if msaorcmsa == 5560;
sort tract_str;
count if tract_str == tract_str[_n-1];
sum tracttomsacmsaallocfactor;
tab tracttomsacmsaallocfactor;
keep tract_str;

save ../tmp_data/new_orleans_cmsa_tracts_1990.dta, replace;
clear;


* create file that maps 2000 tract numbers to the 2000 New Orleans CSA;
insheet using ../raw_data/us_tract_msa_map_2000.csv;

replace tract = round(tract*100);
gen tract_str = string(county, "%05.0f") + string(tract, "%06.0f");

keep if msacmsa == 5560;
sort tract_str;
count if tract_str == tract_str[_n-1];
sum afact;
keep tract_str;

save ../tmp_data/new_orleans_cmsa_tracts.dta, replace;



* Distill raw HMDA files down to only necessary variables;

foreach year in 1997 1998 1999 2000 2001 2002 2003 2004 {;
  use ../raw_data/hmdac`year'.dta;
  count;
  keep if action == 1;
  keep HM5RID locate loanamt code actdate purtype;
  count;
  compress;
  save ../tmp_data/tmp_loans_`year'.dta, replace;
};

* For 2005, drop any data from Katrina or after 8/29/2005;

use ../raw_data/hmdac2005.dta;
count;
keep if action == 1;
keep HM5RID locate loanamt code actdate purtype;
count;
compress;

* keep if before Katrina;
format actdate %td;
drop if actdate > mdy(8,28,2005);

save ../tmp_data/tmp_loans_2005.dta, replace;



* Append the 1990 tract boundary files together 
*  (HMDA switched to 2000 tract boundaries in 2003);

use ../tmp_data/tmp_loans_1997.dta;
foreach year in 1998 1999 2000 2001 2002 {;
  append using ../tmp_data/tmp_loans_`year'.dta;
};
gen year = year(actdate);
tab year;

gen tract_str = string(locate, "%011.0f");
sort tract_str;

compress;

merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts_1990.dta;
tab _merge;
gen nolacsa = (_merge == 3);

* keep only relevant variables;
keep HM5RID tract_str loanamt nolacsa code actdate purtype;

compress;
save ../tmp_data/loans_1997_2002_by_nolacsa.dta, replace;



* Append the 2000 tract boundary files together 

use ../tmp_data/tmp_loans_2003.dta;
foreach year in 2004 2005 {;
  append using ../tmp_data/tmp_loans_`year'.dta;
};
gen year = year(actdate);
tab year;

gen tract_str = string(locate, "%011.0f");
sort tract_str;

compress;

merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts.dta;
tab _merge;
gen nolacsa = (_merge == 3);

* keep only relevant variables;
keep HM5RID tract_str loanamt nolacsa code actdate purtype;

compress;
save ../tmp_data/loans_2003_2005_by_nolacsa.dta, replace;



* Merge both periods together;

use ../tmp_data/loans_1997_2002_by_nolacsa.dta;
append using ../tmp_data/loans_2003_2005_by_nolacsa.dta;

sum;

gen year = year(actdate);
tab year;

gen mdate = ym(year(actdate), month(actdate));
format mdate %tm;
tab mdate;

sort mdate;
merge m:1 mdate using ../raw_data/cpi_allitems_urban_monthly_not_sa.dta;
drop if _merge == 2;
drop _merge;

* put loan amount in year 2005 dollars;
replace loanamt = loanamt * cpi / 195.3;

* generate variable to count the number of loans;
gen numloans=1;


* create variables to examine the share of loans that were securitized or sold;
gen shrsec = 0 if purtype~=.;
replace shrsec = 1 if (purtype >= 1 & purtype <= 5);

gen shrprivsec = 0 if purtype~=.;
replace shrprivsec = 1 if (purtype == 5);

gen shrsold = 0 if purtype~=.;
replace shrsold = 1 if (purtype >= 1 & purtype <= 9);



* find the total amount of loans and loan totals by institution and location;
* for the full pre-Katrina period;

preserve;
collapse (sum) loanamt numloans (mean) shrsec shrprivsec shrsold, by (HM5RID code nolacsa);

reshape wide loanamt numloans shrsec shrprivsec shrsold, i(HM5RID code) j(nolacsa);

gen shr_nolacsa_num_full = numloans1 / (numloans0 + numloans1);
gen shr_nolacsa_bal_full = loanamt1 / (loanamt0 + loanamt1);

gen total_num_full = (numloans0 + numloans1);
gen total_bal_full = (loanamt0 + loanamt1);

rename numloans1 nolacsa_num_full;
rename loanamt1 nolacsa_bal_full;

rename shrsold1 shrsold_full;
rename shrsec1 shrsec_full;

compress;
rename HM5RID hm5rid;
sort hm5rid code;

keep hm5rid code shr_nolacsa_num_full shr_nolacsa_bal_full total_num_full total_bal_full nolacsa_num_full nolacsa_bal_full shrsold_full shrsec_full;

save ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta, replace;
restore;



* use only data from the period of our Katrina panel;
keep if mdate >= ym(2003,7);
collapse (sum) loanamt numloans (mean) shrsec shrprivsec shrsold, by (HM5RID code nolacsa);

reshape wide loanamt numloans shrsec shrprivsec shrsold, i(HM5RID code) j(nolacsa);

gen shr_nolacsa_num_pre = numloans1 / (numloans0 + numloans1);
gen shr_nolacsa_bal_pre = loanamt1 / (loanamt0 + loanamt1);

gen total_num_pre = (numloans0 + numloans1);
gen total_bal_pre = (loanamt0 + loanamt1);

rename numloans1 nolacsa_num_pre;
rename loanamt1 nolacsa_bal_pre;

rename shrsold1 shrsold_pre;
rename shrsec1 shrsec_pre;


compress;
rename HM5RID hm5rid;
sort hm5rid code;

keep hm5rid code shr_nolacsa_num_pre shr_nolacsa_bal_pre total_num_pre total_bal_pre nolacsa_num_pre nolacsa_bal_pre shrsold_pre shrsec_pre;

save ../tmp_data/nolacsa_lending_shares_2002Q3_2005Q2.dta, replace;




*************************************************************************;
* Distill all raw HMDA files down to New Orleans CSA tracts;
*  and standardize variables names;
*************************************************************************;

* Create HUD subprime lender list files;
forvalues y=1997/2005 {;

  insheet using ../raw_data/subprime_`y'_distributed.csv;

  rename id hm5rid;
  rename name subprime_lender_name;
  drop if mh == 2;
  compress;

  keep code hm5rid subprime_lender_name;
  drop if hm5rid == "";
  sort hm5rid code;
  save ../tmp_data/subprime_lender_list_`y'.dta, replace;
  clear;
};


* loop through the code for each year of interest, 1997-2010;

forval i=1997/2002 {;

  use ../raw_data/hmdac`i'.dta;

  gen tract_str = string(locate, "%011.0f");
  sort tract_str;

  * keep only loans made in New Orleans CSA;
  merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts_1990.dta;
  tab _merge;
  keep if _merge == 3;
  drop _merge;

  * keep only relevant variables;
  keep HM5RID action tract_str loanamt code income apprace actdate appdate reason appsex occupy purtype type loanpurp loantype;

  * generate variable to count the number of loans;
  gen numloans=1;

  * generate year variable;
  gen year= `i';

  * want to bring in subprime variable here;
  rename HM5RID hm5rid;
  sort hm5rid code;
  merge m:1 hm5rid code using ../tmp_data/subprime_lender_list_`i'.dta;
  drop if _merge == 2;
  gen subprime = (_merge == 3);
  drop _merge;

  compress;

  save ../tmp_data/katrina_csa_hmdac`i'_c.dta, replace;

  clear;
};


local i = 2003;
  use ../raw_data/hmdac`i'.dta;

  gen tract_str = string(locate, "%011.0f");
  sort tract_str;

  * keep only loans made in New Orleans CSA;
  merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts.dta;
  tab _merge;
  keep if _merge == 3;

  * keep only relevant variables;
  keep HM5RID action tract_str loanamt code income apprace actdate appdate reason appsex occupy purtype type loanpurp loantype;

  * generate variable to count the number of loans;
  gen numloans=1;

  * want to bring in subprime variable here;
  rename HM5RID hm5rid;
  sort hm5rid code;
  merge hm5rid code using ../tmp_data/subprime_lender_list_`i'.dta;
  drop if _merge == 2;
  gen subprime = (_merge == 3);
  drop _merge;

  * generate year variable;
  gen year= `i';
  compress;

  save ../tmp_data/katrina_csa_hmdac`i'_c.dta, replace;



forval i=2004/2005 {;

  use ../raw_data/hmdac`i'.dta;

  gen tract_str = string(locate, "%011.0f");
  sort tract_str;

  * keep only loans made in New Orleans CSA;
  merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts.dta;
  tab _merge;
  keep if _merge == 3;

  * keep only relevant variables;
  keep HM5RID action tract_str loanamt code income APPRACE* hoepa actdate appdate reason appsex occupy purtype type loanpurp loantype;

  * generate variable to count the number of loans;
  gen numloans=1;

  * want to bring in subprime variable here;
  rename HM5RID hm5rid;
  sort hm5rid code;
  merge hm5rid code using ../tmp_data/subprime_lender_list_`i'.dta;
  drop if _merge == 2;
  gen subprime = (_merge == 3);
  drop _merge;

  * generate year variable;
  gen year= `i';
  compress;

  save ../tmp_data/katrina_csa_hmdac`i'_c.dta, replace;

  clear;
};


forval i=2006/2010 {;

  use ../raw_data/hmdac`i'.dta;

  gen tract_str = string(locate, "%011.0f");
  sort tract_str;

  * keep only loans made in New Orleans CSA;
  merge m:1 tract_str using ../tmp_data/new_orleans_cmsa_tracts.dta;
  tab _merge;
  keep if _merge == 3;

  * keep only relevant variables;
  keep HM5RID action tract_str loanamt code income APPRACE* hoepa actdate appdate reason appsex occupy purtype type loanpurp loantype;

  * generate variable to count the number of loans;
  gen numloans=1;

  * generate year variable;
  gen year= `i';
  compress;

  save ../tmp_data/katrina_csa_hmdac`i'_c.dta, replace;

  clear;
};




use ../tmp_data/katrina_csa_hmdac1997_c.dta;

forvalues i = 1998/2010 {;
  append using ../tmp_data/katrina_csa_hmdac`i'_c.dta;
};

replace apprace = APPRACE1 if year >= 2004;
tab year apprace;
count;

replace hm5rid = HM5RID if year >= 2006;

drop APPRACE* HM5RID;
compress;

* put loan amount into real 2000 dollar terms;

gen mdate = ym(year(actdate), month(actdate));
format mdate %tm;
tab mdate;

sort mdate;
merge m:1 mdate using ../raw_data/cpi_allitems_urban_monthly_not_sa.dta;
drop if _merge == 2;
drop _merge;

* put loan amount in year 2005 dollars;
replace loanamt = loanamt * cpi / 195.3;

sort year hm5rid code;

save ../tmp_data/katrina_csa_hmdac_all_c.dta, replace;



*************************************************************************;
* Merge in branch presence by year from FDIC SOD data;
*************************************************************************;

* first create the branch presence indicators;

use ../raw_data/fdic_sod_branchvars_all.dta;

gen branchin_nomsa = (msabr == 35380);
gen branchin_nocsa = (csabr == 406);
gen branchin_ocounty = (stcntybr == 22071);
gen branchin_nocity = (citybr == "New Orleans");
gen branchin_nocity2 = (placenum == 98000 & stnumbr == 22);
gen branchin_lastate = (stnumbr == 22);

collapse (max) branchin_nomsa branchin_nocsa branchin_ocounty branchin_nocity branchin_nocity2 branchin_lastate, by(cert year);

sort year cert;
save ../tmp_data/branch_in_new_orleans.dta, replace;



* create more standarized orgname file;
* this file will map the hm5rid and code from HMDA;
*   to the cert from the FDIC SOD data;

use ../raw_data/hmdapanel.dta;

* drop all irrelevant variables;
keep hm5rid code name* cert*;
drop names*;

* rename the organization name variable, so that it is more distinguishable from the institution name variable;
rename nameor(##) orgname(##);


* generate an id number, unique to each hm5rid, for ease of sorting;
gen id= _n;

* rename variables so they have 4-digit years, to allow for proper conversion from wide to long form;

forval x=0/9 {;
   rename cert0`x' cert200`x';
   rename cert9`x' cert199`x';
   rename name0`x' name200`x';
   rename name9`x' name199`x';
   rename orgname0`x' orgname200`x';
   rename orgname9`x' orgname199`x';
};

rename cert10 cert2010;
rename name10 name2010;
rename orgname10 orgname2010;

* reshape data from wide to long form;
reshape long orgname name cert, i(id) j(year);

save ../tmp_data/katrina_HMDA_orgnames.dta, replace;




* Next merge in the orgnames;

use ../tmp_data/katrina_csa_hmdac_all_c.dta;

sort year hm5rid code;
merge m:1 year hm5rid code using ../tmp_data/katrina_HMDA_orgnames.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

count;
count if cert==.;
count if cert==0;

tab code;
tab code if (cert == 0 | cert == .);
* don't know about branches if HUD or NCUA is regulator;

* Now merge in the branch presence indicators;

sort year cert;
merge m:1 year cert using ../tmp_data/branch_in_new_orleans.dta;
drop if _merge == 2;
drop _merge;

* make branch variables assuming hud regulated mortgage companies have no branches;
foreach v in branchin_nomsa branchin_nocsa branchin_ocounty branchin_nocity branchin_nocity2 branchin_lastate {;
	gen `v'_hudnb = `v';
	replace `v'_hudnb = 0 if code == 7;
};

sort year hm5rid code;
compress;

save ../tmp_data/katrina_csa_tracts_hmda_microdata.dta, replace;



************************************************************;
* pair down microdata file to katrina flood depth data tract;
*  mortgages.  we also have to drop pre 2003 data because it;
*  is in 1990 tract boundaries;
************************************************************;

drop if year < 2003;

sort tract_str;
merge m:1 tract_str using ../raw_data/depthcoverage_tracts.dta;
keep if _merge == 3;
drop _merge;

save ../tmp_data/depth_coverage_tracts_hmda_microdata_post2002.dta, replace;



************************************************************;
* Make tract-level variables.  THis way we can convert the;
* pre 2003 data to year 2000 tract boundaries;
************************************************************;

* Start by converting pre 2003 HMDA data to 2000 tract boundaries;

use ../tmp_data/katrina_csa_tracts_hmda_microdata.dta;

* only keep loans that were made;
keep if action == 1;

drop if actdate > mdy(8,28,2005);

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta;
drop if _merge == 2;
drop _merge;

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_2002Q3_2005Q2.dta;
drop if _merge == 2;
drop _merge;

keep if year < 2003;

gen obs = 1;

collapse (sum) obs (mean) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre, by(tract_str);

sum branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre;

rename tract_str tract_id_1990;
sort tract_id_1990; 
merge 1:m tract_id_1990 using ../raw_data/relationshipfile1990to2000.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

foreach v in branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre {;
  replace `v' = `v' * percent1990tract / 100;
};

collapse (sum) obs (sum) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre, by(tract_id_2000);
rename tract_id_2000 tract_str;

sort tract_str;
merge 1:1 tract_str using ../raw_data/depthcoverage_tracts.dta;
keep if _merge == 3;
drop _merge;

sum branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre obs;

gen tract_boundary = 1990;

compress;
save ../tmp_data/katrina_pre2003_tractmeans.dta, replace;



* Next take means of the 2003-Katina data;

use ../tmp_data/katrina_csa_tracts_hmda_microdata.dta;

* only keep loans that were made;
keep if action == 1;

drop if actdate > mdy(8,28,2005);

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta;
drop if _merge == 2;
drop _merge;

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_2002Q3_2005Q2.dta;
drop if _merge == 2;
drop _merge;

keep if year >= 2003;

gen obs = 1;

collapse (sum) obs (mean) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre, by(tract_str);

sort tract_str;
merge 1:1 tract_str using ../raw_data/depthcoverage_tracts.dta;
keep if _merge == 3;
drop _merge;

gen tract_boundary = 2000;

compress;
save ../tmp_data/katrina_post2002_tractmeans.dta, replace;


sort tract_str;
merge 1:1 tract_str using ../tmp_data/katrina_pre2003_tractmeans.dta;
keep if _merge == 3;
drop _merge;

append using ../tmp_data/katrina_pre2003_tractmeans.dta;

collapse (mean) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre [aw=obs], by(tract_str);

compress;
save ../tmp_data/katrina_tractmeans.dta, replace;

sum branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre, d;



***************************************************************;
* files to be used as inputs for main Katrina do file:
* copy these over to raw_data folder in main area after running;
* ../tmp_data/depth_coverage_tracts_hmda_microdata_post2002.dta;
* ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta;
* ../tmp_data/nolacsa_lending_shares_2002Q3_2005Q2.dta;
* ../tmp_data/katrina_tractmeans.dta;
***************************************************************;

log close;
