# delimit;
set more off;

log using ../logs/katrina_paper.txt, text replace;

use ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta;

gen bg_str = substr(block_str, 1, 12);
sort bg_str;
merge m:1 bg_str using ../tmp_data/census2000_blck_grp.dta, update;
drop if _merge ==2;
drop _merge;

sort block_str;
merge 1:1 block_str using ../raw_data/la_census2000_block_age.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

rename fxs001 blockpop2000;
drop fym*;

sort block_str;
merge 1:1 block_str using ../raw_data/la_census2000_block_propaa.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

gen cat_propaa = 1 if propaa < 0.05;
replace cat_propaa = 2 if propaa >= 0.05 & propaa < 0.25;
replace cat_propaa = 3 if propaa >= 0.25 & propaa < 0.5;
replace cat_propaa = 4 if propaa >= 0.5 & propaa < 0.75;
replace cat_propaa = 5 if propaa >= 0.75 & propaa < 0.95;
replace cat_propaa = 6 if propaa >= 0.95 & propaa ~= .;

tab cat_propaa qdepth;

gen tract_str = substr(block_str, 1, 11);
sort tract_str;

table qdepth, c(sum blockpop2000);


* census vars already in 2005 dollars;

// Table 1 - top panel;
tab qdepth;
table qdepth [fw=blockpop2000], c(mean meandepthd0831 mean meanelev mean propa);

// Table 1 - middle panel;
table qdepth [fw=blockpop2000], c(mean medhhinc mean povrate mean medoohval mean foo);
table qdepth [fw=blockpop2000], c(mean fba mean f65p mean faa mean fhisp);

sum maxmeandepth  meanelev propa;

gen meanelev_sq  = meanelev^2;
gen maxelev_sq = maxelev^2;
gen minelev_sq = minelev^2;

gen meanelev_cub = meanelev^3;
gen maxelev_cub = maxelev^3;
gen minelev_cub = minelev^3;

gen propa_sq = propa^2;
gen propa_cu = propa^3;

gen propa_x_elev = propa * meanelev;


* Table 2;

* Table 2 - Column 1;
reg maxmeandepth meanelev minelev maxelev propa if lmedoohval ~= ., robust;
* Table 2 - Column 2;
reg maxmeandepth meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu propa propa_sq propa_cu propa_x_elev if lmedoohval ~= ., robust;

* Table 2 - Column 3;
reg maxmeandepth lmedoohval if lmedoohval ~= ., robust;
* Table 2 - Column 4;
reg maxmeandepth meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu propa propa_sq propa_cu propa_x_elev lmedoohval if lmedoohval ~= ., robust;
* Table 2 - Column 5;
reg maxmeandepth meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu propa propa_sq propa_cu propa_x_elev lmedoohval lmedhhinc foo faa fhisp f65p povrate fba if lmedoohval ~= ., robust;

clear;


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

* Table 1 stats - bottom panel;

* Equifax stats from 2005Q2;
table qdepth if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean riskscore mean bal_all_tot_imp mean gt1_home_tot_imp mean gt1_all_90);







use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

sum riskscore if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= .  & num_all_tot~=., d;

disp("Median Risk Score: `r(p50)'");


* stats for paper section 4.1.4;
sum bal_bcret_tot if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=.;
tab had_cc if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=.;
table had_cc if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean bal_bcret_tot);


tab qdepth had_cc if qdate==yq(2005,3) & qdepth>=0 & pres_during_katrina ==1 & fullsample0208==1 & num_all_tot~=.;
tab qdepth cc_const if qdate==yq(2005,3) & qdepth>=0 & pres_during_katrina ==1 & fullsample0208==1 & num_all_tot~=.;

table qdepth if qdate == yq(2005,2) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean gt1_bcret_tot);
table qdepth if qdate == yq(2005,4) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean gt1_bcret_tot);

table qdepth if qdate == yq(2005,2) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean maxed_out);
table qdepth if qdate == yq(2005,4) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean maxed_out);

table qdepth if qdate == yq(2005,2) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean hic_bcret_tot);
table qdepth if qdate == yq(2005,4) & pres_during_katrina == 1 & fullsample0208==1 & num_all_tot~=., c(mean hic_bcret_tot);




* stats for Justin's zip code table;
tab zcta5 qdepth if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=.;

table zcta5 if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean riskscore mean bal_all_tot_imp  mean gt1_home_tot_imp mean gt1_all_90);
table zcta5 if qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean bal_home_tot_imp);
table zcta5 if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean bal_home_tot_imp);
table zcta5 if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean age);

sum sameblock3yr if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., d;


table zcta5 if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean sameblock1yr mean sameblock3yr);

table zcta5 if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean nola1yr mean nola3yr);

table zcta5 if had_mtg == 1 & qdate==yq(2005,2) & fullsample0208 == 1 & pres_during_katrina==1 & num_all_tot~=., c(mean nocsa1yr mean nocsa3yr);


* shows that quarter of observations lived in block that was more than 96% African American;
* shows that quarter of observations lived in tract that was more than 92% African American;
sum propaa tract_propaa if qdate==yq(2005,3) & pres_during_katrina ==1 & fullsample0208 ==1, d;


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .;


* Table 3;
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

clear matrix;

* Table 3 Column 1;

* pre/post flood depth quartiles;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];


* Table 3 Column 2;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];




* Table 3 Column 3;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* census block group ccontrols;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];


* Table 3 Column 4;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* adding block group demgraphic characteristics;
* controlling for age;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu 
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];



* Table 3 Column 5;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding census tract FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(tract_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];



* Table 3 Column 6;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding census block FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];



* Table 3 Column 7;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];

matrix list results_specs;

clear matrix;


*** Table 4;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


* Table 4 which repeats Table 3 Column 7;
*  specification for each type of debt category;

foreach v in
  bal_home_tot_imp
  bal_bcret_tot
  bal_auto_tot 
  bal_stdln_tot
{;


* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg `v'
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];
};

foreach v in
  gt1_all_90
  riskscore
{;
areg `v'
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];
};

 

* Migration: need to keep people who moved away before Katrina;
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

foreach v in
  leftcsageq3yr
{;

sum `v' if ( (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .;
 
areg `v'
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];
};
matrix list accttypes;

clear matrix;

clear;







*** Table 5;
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta;


* Table 5;
* Row 1;

table qdepth if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1, c(mean shr_bal_claim);

* Table 5;
* Row 2;

reg fstart post if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdate>=yq(2005,1) & qdate<=yq(2006,1) & qdepth == 0, robust;
reg fstart post if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdate>=yq(2005,1) & qdate<=yq(2006,1) & qdepth == 1, robust;
reg fstart post if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdate>=yq(2005,1) & qdate<=yq(2006,1) & qdepth == 2, robust;
reg fstart post if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdate>=yq(2005,1) & qdate<=yq(2006,1) & qdepth == 3, robust;
reg fstart post if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdate>=yq(2005,1) & qdate<=yq(2006,1) & qdepth == 4, robust;

* Table 5;
* Row 3 - Calculations;

* Calculate ratio of pre-Katrina mortgage balances to rebuilding dollars;
preserve;

keep if qdate == yq(2005,2);
gen tot_mtg_bal = bal_home_tot_imp;
collapse (sum) tot_mtg_bal (mean) qdepth, by(block_str_2005q3);
tab qdepth;
rename block_str_2005q3 block_str;
replace tot_mtg_bal = tot_mtg_bal * 20;
replace tot_mtg_bal = 0 if tot_mtg_bal == .;

drop if qdepth<0 | qdepth==.;

sort block_str;
merge m:1 block_str using ../tmp_data/home_sales_by_block_2qafter_katrina.dta;
drop if _merge ==2;
drop _merge;



gen county_code = substr(block_str, 1, 5);
tab county_code;
keep if county_code == "22071";
drop county_code;

count if price == .;
count;

replace price = 0 if price == .;

sort block_str;
merge m:1 block_str using ../raw_data/blocklevel_assessors_info_for_GallagherHartley.dta;
drop if _merge == 2;
drop _merge;

replace tot_valchange = 0 if tot_valchange == .;

collapse (sum) price tot_mtg_bal tot_valchange, by(qdepth);

gen shr_sales_mtg_bal = price / tot_mtg_bal;
gen shr_rebuild = tot_valchange / tot_mtg_bal;


* Table 5;
* Row 3;

table qdepth, c(mean shr_sales_mtg_bal mean shr_rebuild);
restore;

sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/mortgage_tradeline_aggregated_to_cid.dta;

tab had_mtg _merge if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & qdate==yq(2005,3);
* the merge looks good;

drop _merge;

* table looking at mortgage account narrative codes for footnote in end of section 5.2;

table qdate if pres_during_katrina == 1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & had_mtg==1 & qdepth == 4, c(mean disaster mean acctclosedco  mean acctclosedl  mean acctclosedb  mean acctclosedu);

clear;








*** Table 6 is by neighborhood - Justin created;


*** Table 7;

* Local Lender regressions;
use ../tmp_data/tmp_local_nonlocal.dta;

* Correlation mentioned in Section 5.3;
corr nl1 nl2 nl3 nl4 nl5 if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4);

tab blkaatq nl2 if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1;

clear matrix;

sum gt1_home_tot_imp_had_mtg if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=., d;

* Table 7;
* Column 1;
areg gt1_home_tot_imp_had_mtg
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];

* Table 7;
* Column 2;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];


* Table 7;
* Column 3;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];


* Table 7;
* Column 4;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];




* Table 7;
* Column 5;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];

* Table 7;
matrix list results;


sum shr_nolacsa_num_full if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,3)  & nl10 ~=. & propaa ~=. & riskscore ~=. & gt1_home_tot_imp_had_mtg~=., d;

sum shr_nolacsa_bal_full if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,3)  & nl10 ~=. & propaa ~=. & riskscore ~=. & gt1_home_tot_imp_had_mtg~=., d;

sum branchin_nocsa_hudnb if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,3)  & nl10 ~=. & propaa ~=. & riskscore ~=. & gt1_home_tot_imp_had_mtg~=., d;

clear;



*** Figures **********;

*** Figure 1;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

collapse (mean) bal_all_tot_imp, by(qdate qdepth);
reshape wide bal_all_tot_imp, i(qdate) j(qdepth);
label var qdate "Quarter of Year";
label var bal_all_tot_imp0 "Not Flooded";
label var bal_all_tot_imp1 "Least Flooded Quartile";
label var bal_all_tot_imp4 "Most Flooded Quartile";

tsset qdate;
twoway (connected bal_all_tot_imp0 qdate, lcolor(blue) msymbol(X) mcolor(blue)) (connected bal_all_tot_imp1 qdate, lcolor(green) msymbol(S) mcolor(green)) (connected bal_all_tot_imp4 qdate, lcolor(red) msymbol(O) mcolor(red)), ytitle("Total Debt Balance") xline(182, lcolor(black)) xlabel(172(4)192) xmtick(170(1)194)
scheme(s2mono) plotregion(fcolor(white)) graphregion(fcolor(white));

graph save ../figures/figure1.gph, replace;

clear;

*** Figure 2 is created in ArcGIS;

*** Figure 3;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

areg bal_all_tot_imp

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Total Debt Balance (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black)) ylabel(-15000(5000)10000);


graph save ../figures/figure3.gph, replace;



*** Figure 4;

areg bal_home_tot_imp

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, title(Panel A) ytitle("Home Loans Balance (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black)) ylabel(-15000(10000)5000) ymtick(-15000(5000)5000);


graph save ../figures/figure4_panela.gph, replace;
!mv ../tmp_data/temp.dta ../figures/figure4_panela.dta;


areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu

        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 

        lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
                   
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, title(Panel B) ytitle("Credit Card Balance (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black))  ylabel(-500(1000)1500) ymtick(-500(500)1500);


graph save ../figures/figure4_panelb.gph, replace;
!mv ../tmp_data/temp.dta ../figures/figure4_panelb.dta;



areg gt1_all_90

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, title(Panel C) ytitle("Share 90+ Days Delinquent") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));


graph save ../figures/figure4_panelc.gph, replace;
!mv ../tmp_data/temp.dta ../figures/figure4_panelc.dta;




areg riskscore

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, title(Panel D) ytitle("Equifax Risk Score (TM) Points") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));


graph save ../figures/figure4_paneld.gph, replace;
!mv ../tmp_data/temp.dta ../figures/figure4_paneld.dta;



* Code to create and combine panels from datasets of coefficients;
#d cr

* Files that contain the data for each of the panels in order
local files = "figure4_panela figure4_panelb figure4_panelc figure4_paneld"

* Getting the number of files
local num = wordcount("`files'")

* Seperating the file names
tokenize "`files'"

* Loop to produce each of the panels
forvalues i=1/`num'{
	* use the appropiate file for each panel, by using the ith file in the local files
	use "../figures/``i''",clear
	
	* Caculating the letter for panel label 
	local panelLetter = char(64+`i')
	* Create panel A with the debt data
	if `i'==1{
		#d
		twoway /* Graphing the least flooded quartile groups in green */
			(connected yvar1 luci1 llci1 ruci1 rlci1 xvar, lpattern(solid dot dot dot dot) 
				lcolor(green green green green green) msymbol(S Sh Sh Sh Sh) 
				mcolor(green green green green green) 
				yline(-20000(5000)10000, lcolor(gs8)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))) 
			/* Graphing the most flooded quartile groups in red */
			(connected yvar2 luci2 llci2 ruci2 rlci2 xvar, lpattern(solid dot dot dot dot) 
				lcolor(red red red red red) msymbol(O Oh Oh Oh Oh) 
				mcolor(red red red red red) 
				yline(-20000(5000)10000, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))), 
			legend(order(1 "Least Flooded Quartile" 6 "Most Flooded Quartile")) /*Add legend*/ 
			title("Panel `panelLetter'",position(1)ring(0)) xtitle("Quarter of Year",size(small)) ytitle("Home Loans Balance (Dollars)",size(small))   legend(off) /*Add titles*/
			ylabel(-20000(10000)10000, labsize(small)) xlabel(2003(1)2008,labsize(small)) xmtick(2002.5(0.25)2008.5) ymtick(-20000(5000)10000) scheme(s2mono) /*Labels and tick marks*/
			plotregion(fcolor(white)) graphregion(fcolor(white)) name("../figures/nbr_fig1", replace) nodraw /*Set color of the graph background*/
		;
		#d cr
	}
	
	* Create panel B with the credit balance data
	if `i'==2{
		#d
		twoway /* Graphing the least flooded quartile groups in green */
			(connected yvar1 luci1 llci1 ruci1 rlci1 xvar, lpattern(solid dot dot dot dot) 
				lcolor(green green green green green) msymbol(S Sh Sh Sh Sh) 
				mcolor(green green green green green) 
				yline(-1000(500)1500, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black)))  
			/* Graphing the most flooded quartile groups in red */
			(connected yvar2 luci2 llci2 ruci2 rlci2 xvar, lpattern(solid dot dot dot dot) 
				lcolor(red red red red red) msymbol(O Oh Oh Oh Oh) 
				mcolor(red red red red red) 
				yline(-1000(500)1500, lcolor(gs14))  
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))),  
			legend(order(1 "Least Flooded Quartile" 6 "Most Flooded Quartile")) /*Add legend*/ 
			title("Panel `panelLetter'",position(1)ring(0)) xtitle("Quarter of Year",size(small)) ytitle("Credit Card Balance (Dollars)",size(small))   legend(off) /*Add titles*/
			ylabel(-1000(500)1500, labsize(small)) xlabel(2003(1)2008,labsize(small)) xmtick(2002.5(0.25)2008.5) scheme(s2mono)  /*Labels and tick marks*/
			plotregion(fcolor(white)) graphregion(fcolor(white)) name("../figures/nbr_fig2", replace) nodraw /*Set color of the graph background*/
		;
		#d cr
	}
	
	* Create panel C with the delinquency data  
	if `i'==3{
		#d
		twoway /* Graphing the least flooded quartile groups in green */
			(connected yvar1 luci1 llci1 ruci1 rlci1 xvar, lpattern(solid dot dot dot dot) 
				lcolor(green green green green green) msymbol(S Sh Sh Sh Sh) 
				mcolor(green green green green green) 
				yline(-.04(.02).04, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black)))  
			/* Graphing the most flooded quartile groups in red */
			(connected yvar2 luci2 llci2 ruci2 rlci2 xvar, lpattern(solid dot dot dot dot) 
				lcolor(red red red red red) msymbol(O Oh Oh Oh Oh) 
				mcolor(red red red red red) 
				yline(-.04(.02).04, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))), 
			legend(order(1 "Least Flooded Quartile" 6 "Most Flooded Quartile")) /*Add legend*/ 
			title("Panel `panelLetter'",position(1)ring(0)) xtitle("Quarter of Year",size(small)) ytitle("Share 90+ Days Delinquent",size(small))   legend(off) /*Add titles*/
			ylabel(-.04(.02).04, labsize(small)) xlabel(2003(1)2008,labsize(small)) xmtick(2002.5(0.25)2008.5) scheme(s2mono) /*Labels and tick marks*/
			plotregion(fcolor(white)) graphregion(fcolor(white)) name("../figures/nbr_fig3", replace) nodraw /*Set color of the graph background*/
		;
		#d cr
	}
	
	* Create panel D with the Equifax data
	if `i'==4{
		#d
		twoway /* Graphing the least flooded quantile groups in green */
			(connected yvar1 luci1 llci1 ruci1 rlci1 xvar, lpattern(solid dot dot dot dot) 
				lcolor(green green green green green) msymbol(S Sh Sh Sh Sh) 
				mcolor(green green green green green) 
				yline(-10(5)10, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))) 
			/* Graphing the most flooded quantile groups in red */
			(connected yvar2 luci2 llci2 ruci2 rlci2 xvar, lpattern(solid dot dot dot dot) 
				lcolor(red red red red red) msymbol(O Oh Oh Oh Oh) 
				mcolor(red red red red red) 
				yline(-10(5)10, lcolor(gs14)) 
				yline(0, lcolor(black)) xline(2005.5, lcolor(black))), 
			legend(order(1 "Least Flooded Quartile" 6 "Most Flooded Quartile"))  /* Add legend*/ 
			title("Panel `panelLetter'",position(1)ring(0)) xtitle("Quarter of Year",size(small)) ytitle("Equifax Risk Score (TM) Points",size(small))   legend(off)  /*Add titles*/
			ylabel(-10(5)10, labsize(small)) xlabel(2003(1)2008,labsize(small)) xmtick(2002.5(0.25)2008.5) scheme(s2mono)  /*Labels and tick marks*/
			plotregion(fcolor(white)) graphregion(fcolor(white)) name("../figures/nbr_fig4", replace) nodraw /*Set color of the graph background*/
		;
		#d cr
	}
}

* Combine the four panels into a single graph
grc1leg ../figures/nbr_fig1 ../figures/nbr_fig2 ../figures/nbr_fig3 ../figures/nbr_fig4, cols(2) rows(2) legendfrom(nbr_fig4) plotregion(fcolor(white)) graphregion(fcolor(white))
graph save ../figures/figure4.gph, replace
#d ;
clear;




    
* Create Figure 5;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


drop branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre;
rename tract_str_2005q3 tract_str;
sort tract_str;
merge m:1 tract_str using ../tmp_data/katrina_tractmeans.dta;
drop _merge;
rename tract_str tract_str_2005q3;


* Need to determine Local non-Local threshold.  split estimation sample in half;

sum shr_nolacsa_num_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh2 = `r(p50)';
disp(`nlthresh2');

clear;


use ../tmp_data/depth_coverage_tracts_hmda_microdata_post2002.dta;
keep if action == 1;
gen qdate = yq(year(actdate), quarter(actdate));
format qdate %tq;

sort tract_str;
merge m:1 tract_str using ../tmp_data/rough_tract_floooddepth.dta;
drop if _merge == 2;
drop _merge;

rename hm5rid HM5RID;
sort HM5RID code;
merge m:1 HM5RID code using ../tmp_data/shrnolacsa_by_lender.dta;
drop if _merge == 2;
drop _merge;

keep if qdepth == 4;

sum shrnolacsa, d;

* This threshold is the median of the share local variable used in Table 7;
gen nonlocal = (shrnolacsa < 0.2149);
replace nonlocal = . if shrnolacsa == .;

sum shrnolacsa if nonlocal == 0;
sum shrnolacsa if nonlocal == 1;

drop if nonlocal == .;

collapse (sum) numloans loanamt, by(qdate nonlocal);

reshape wide numloans loanamt, i(qdate) j(nonlocal);

tsset qdate, quarterly;

twoway (connected numloans0 qdate, lcolor(blue) msymbol(X) mcolor(blue)) (connected numloans1 qdate, lcolor(red) msymbol(O) mcolor(red)) if qdate>=yq(2003,1) & qdate<=yq(2008,3), legend(lab(1 "Local") lab(2 "Non-Local")) xtitle("Quarter of Year") ytitle("Quarterly Number of Mortgages Originated") xline(182, lcolor(black) lpattern(dash)) xlabel(172(4)192) xmtick(170(1)194)
scheme(s2mono) plotregion(fcolor(white)) graphregion(fcolor(white));

* Figure 5;
graph save ../figures/figure5.gph, replace; 





log close;
