# delimit;
set more off;


log using ../logs/katrina_prepare_data.txt, text replace;



* create mapping of 2000 census blocks to zip codes;

insheet using ../raw_data/louisiana_block_zip_map_2000.csv;

replace tract = round( tract * 100 );
gen block_str = string(county, "%05.0f") + string(tract, "%06.0f") + string(block, "%04.0f");

sum afact;

keep block_str zcta5;
sort block_str;

save ../tmp_data/block_zip_mp_2000.dta, replace;

keep zcta5;
sort zcta5;
drop if zcta5 == zcta5[_n-1];
sort zcta5;

save ../tmp_data/louisiana_zips.dta, replace;



* get Flood insurance claims data into useful format;

use ../raw_data/LA_pif_clms.dta;

rename zip zcta5;
sort zcta5;
merge m:1 zcta5 using ../tmp_data/louisiana_zips.dta;
keep if _merge == 3;
drop _merge;

sort id zcta5 flood_zone sfha year;
count if id==id[_n-1] & zcta5==zcta5[_n-1] & flood_zone==flood_zone[_n-1] & sfha==sfha[_n-1] & year==year[_n-1];

collapse (sum) claims claim_dollars pif, by(zcta5 sfha year) fast;
sort zcta5 sfha year;
save ../tmp_data/claims_panel.dta, replace;

keep if year == 2005;
drop year;
sort zcta5 sfha;

tab sfha;

save ../tmp_data/claims_2005.dta, replace;


use ../tmp_data/claims_panel.dta, replace;

keep if year == 2004;
drop year;
sort zcta5 sfha;

tab sfha;
keep zcta5 sfha pif;
rename pif pif2004;

save ../tmp_data/policies_in_force_2004.dta, replace;




* Use CoreLogic Parcel Level tax assessment data to measure rebuilding;
use ../raw_data/flooddepthcoverage_tax_assesor_data.dta;

* keep only residential transactions;
keep if residential_flag == "Y";

* keep only tranacstions with a census block that is knowm;
drop if block_str == "";

sort prop_id_dw assd_year;

tab assd_year;

count if prop_id_dw == prop_id_dw[_n-1] & assd_total_value ~= assd_total_value[_n-1];

tab assd_year if prop_id_dw == prop_id_dw[_n-1] & assd_total_value ~= assd_total_value[_n-1];

keep prop_id_dw assd_year assd_total_value block_str;
drop if assd_year == .;

sum assd_total_value, d;
* it looks like there are errors in some assessed values;
* once we drop what looks like 2 value concatented cause over $100M values;
* the highest value is $7M;
count if assd_total_value ~= . & assd_total_value > 100000000;
drop if assd_total_value ~= . & assd_total_value > 100000000;
sum assd_total_value, d;

gen parish = substr(block_str, 1, 5);
tab parish;


* St. Bernard Parish is not at 10% value in 2004, but at 100%;
sum assd_total_value if parish=="22087" & assd_year == 2004, d;
replace assd_total_value =  assd_total_value / 10 if parish=="22087" & assd_year == 2004;
sum assd_total_value if parish=="22087" & assd_year == 2004, d;
drop parish;


* convert to 2005 dollars;
rename assd_year year;
sort year;
merge m:1 year using ../raw_data/cpi_allitems_urban_annual.dta;
drop if _merge == 2;
drop _merge;
rename year assd_year;
replace assd_total_value = assd_total_value * 195.3 / cpi;
drop cpi;



reshape wide assd_total_value, i(prop_id_dw) j(assd_year);

drop if assd_total_value2003 == . & assd_total_value2004 == . & assd_total_value2005 == .;

gen prekatrina_year = 2005 if assd_total_value2005 ~= .;
gen prekatrina_value = assd_total_value2005;
replace prekatrina_year = 2004 if assd_total_value2004 ~= . & prekatrina_value == .;
replace prekatrina_value = assd_total_value2004 if prekatrina_value == .;
replace prekatrina_year = 2003 if assd_total_value2003 ~= . & prekatrina_value == .;
replace prekatrina_value = assd_total_value2003 if prekatrina_value == .;

gen postkatrina_year = 2007 if assd_total_value2007 ~= .;
gen postkatrina_value = assd_total_value2007;
replace postkatrina_year = 2008 if assd_total_value2008 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2008 if postkatrina_value == .;
replace postkatrina_year = 2009 if assd_total_value2009 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2009 if postkatrina_value == .;
replace postkatrina_year = 2010 if assd_total_value2010 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2010 if postkatrina_value == .;
replace postkatrina_year = 2011 if assd_total_value2011 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2011 if postkatrina_value == .;
replace postkatrina_year = 2012 if assd_total_value2012 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2012 if postkatrina_value == .;
replace postkatrina_year = 2013 if assd_total_value2013 ~= . & postkatrina_value == .;
replace postkatrina_value = assd_total_value2013 if postkatrina_value == .;


gen postkatrina_year2 = 2009 if postkatrina_year < 2009 & assd_total_value2009 ~= .;
gen postkatrina_value2 = assd_total_value2009 if postkatrina_year < 2009 & assd_total_value2009 ~= .;
replace postkatrina_year2 = 2010 if postkatrina_year < 2010 & assd_total_value2010 ~= . & postkatrina_value2 == .;
replace postkatrina_value2 = assd_total_value2010 if postkatrina_year < 2010 & assd_total_value2010 ~= . & assd_total_value2010 ~= postkatrina_value2;
replace postkatrina_year2 = 2011 if postkatrina_year < 2011 & assd_total_value2011 ~= . & postkatrina_value2 == .;
replace postkatrina_value2 = assd_total_value2011 if postkatrina_year < 2011 & assd_total_value2011 ~= . & assd_total_value2011 ~= postkatrina_value2;
replace postkatrina_year2 = 2012 if postkatrina_year < 2012 & assd_total_value2012 ~= . & postkatrina_value2 == .;
replace postkatrina_value2 = assd_total_value2012 if postkatrina_year < 2012 & assd_total_value2012 ~= . & assd_total_value2012 ~= postkatrina_value2;
replace postkatrina_year2 = 2013 if postkatrina_year < 2013 & assd_total_value2013 ~= . & postkatrina_value2 == .;
replace postkatrina_value2 = assd_total_value2013 if postkatrina_year < 2013 & assd_total_value2013 ~= . & assd_total_value2013 ~= postkatrina_value2;



gen prebutnopost = 0 if prekatrina_value ~= .;
replace prebutnopost = 1 if postkatrina_value == .;

gen prebutnopost2 = 0 if prekatrina_value ~= .;
replace prebutnopost2 = 1 if postkatrina_value2 == .;

tab prebutnopost;
tab prebutnopost2;



gen pct_chg = (postkatrina_value - prekatrina_value) / prekatrina_value;
gen pct_chg2 = (postkatrina_value2 - postkatrina_value) / postkatrina_value;

* Parcels with both a pre-Katrina and post-Katrina assesed value;
count if pct_chg ~= .;
keep if pct_chg ~= .;

count if pct_chg > 0 & pct_chg ~= .;
count if pct_chg <= 0;

gen ddamage = 0 if pct_chg ~= .;
replace ddamage = 1 if pct_chg < -0.3 & pct_chg ~= .;

gen drebuilt = 0 if pct_chg2 ~= . | prebutnopost2 == 1;
replace drebuilt = 1 if pct_chg2 >= 0.43 & pct_chg2 ~= .;

tab ddamage drebuilt;

gen ddamage2 = 0 if pct_chg ~= .;
replace ddamage2 = 1 if pct_chg < -0.5 & pct_chg ~= .;

gen drebuilt2 = 0 if pct_chg2 ~= . | prebutnopost2 == 1;
replace drebuilt2 = 1 if pct_chg2 >= 1 & pct_chg2 ~= .;

gen drebuiltcdamage = ddamage * drebuilt;
gen drebuiltcdamage2 = ddamage2 * drebuilt2;

tab ddamage2 drebuilt2;
tab ddamage2 drebuiltcdamage2;

tab prekatrina_year if prekatrina_year~=. & postkatrina_year~=.  & postkatrina_year2~=.;
tab postkatrina_year if prekatrina_year~=. & postkatrina_year~=.  & postkatrina_year2~=.;
tab postkatrina_year2 if prekatrina_year~=. & postkatrina_year~=.  & postkatrina_year2~=.;

tab prekatrina_year;
tab postkatrina_year;
tab postkatrina_year2;

replace block_str = trim(block_str);

* Create block level and zip code-level measures of damage and rebuilding;
sort block_str;
merge m:1 block_str using ../tmp_data/block_zip_mp_2000.dta;
tab _merge;
drop if _merge == 2;
drop _merge;


keep block_str zcta5 prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2;

sort block_str;
save ../tmp_data/parcel_level_data.dta, replace;

gen numparcels = 1 if pct_chg ~= .;

preserve;
drop if block_str == "";
collapse (sum) numparcels (mean) prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2, by(block_str) fast;

foreach v in numparcels prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2
{;
  rename `v' parc_`v';
};
compress;
sort block_str;
save ../tmp_data/parcel_level_means_by_block.dta, replace;
restore;


drop if zcta5 == "";

preserve;
collapse (sum) numparcels (mean) prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2, by(zcta5) fast;

drop if numparcels <= 1;

foreach v in numparcels prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2
{;
  rename `v' parc_`v';
};
compress;
sort zcta5;
saveold ../tmp_data/parcel_level_means_by_zip.dta, replace;
restore;

preserve;
keep if ddamage == 1;
collapse (sum) numparcels (mean) prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2, by(zcta5) fast;

drop if numparcels <= 1;

foreach v in numparcels prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2
{;
  rename `v' dam1_`v';
};
compress;
sort zcta5;
saveold ../tmp_data/parcel_level_means_by_zip_dam1.dta, replace;
restore;

keep if ddamage2 == 1;
collapse (sum) numparcels (mean) prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2, by(zcta5) fast;

drop if numparcels <= 1;

foreach v in numparcels prekatrina_year prekatrina_value postkatrina_year postkatrina_value postkatrina_year2 postkatrina_value2 pct_chg pct_chg2 ddamage drebuilt ddamage2 drebuilt2 drebuiltcdamage drebuiltcdamage2
{;
  rename `v' dam2_`v';
};
compress;
sort zcta5;
saveold ../tmp_data/parcel_level_means_by_zip_dam2.dta, replace;





* Create file with all cids living in cities of Baton Rouge, Memphis, or St. Louis in 2005Q3;

use ../raw_data/frbnyccp_all_primary_cid_mtg_fcl_vars.dta;
keep if ( year(qtr)==2005 & quarter(qtr) == 3);
keep if (state == "LA" | state == "MO" | state == "TN");
gen statecode = "22" if state == "LA";
replace statecode = "29" if state == "MO";
replace statecode = "47" if state == "TN";

gen block_str = statecode + county_code + census_tract + census_block;
sort block_str;

merge m:1 block_str using ../raw_data/batonrouge_memphis_stlouis_blocks.dta;
keep if _merge == 3;

sort cid;
keep cid block_str;

save ../tmp_data/primary_cid_in_batonrouge_memphis_stlouis_during_katrina.dta, replace;

keep cid;
outsheet using ../tmp_data/primary_cid_in_batonrouge_memphis_stlouis_during_katrina.csv, comma replace;




* Create imputation files from mortgage tradeline data;

foreach file in depthcoverage_ever pres_batonrouge_memphis_stlouis_2005q3 {;

use ../raw_data/mortgage_tl_`file'.dta, clear;

gen qdate = yq(year(qtr), quarter(qtr));
format qdate %tq;


collapse (min) minbal = balance (max) maxbal = balance (min) minpmt = payment (max) maxpmt = payment, by(cid tlid qdate) fast;

egen tlidnum = group(tlid);
tsset tlidnum qdate;
tsfill;

gen nonreport = 1 if tlid == "";

* How many pre-non reporting periods there are;
count if f1.nonreport == 1 & nonreport ~= 1;
* 9372;
sum minbal maxbal if f1.nonreport == 1 & nonreport ~= 1, d;

* How many post-non reporting periods there are;
count if l1.nonreport == 1 & nonreport ~= 1;
sum minbal maxbal if l1.nonreport == 1 & nonreport ~= 1, d;

preserve;

sort tlidnum qdate;
keep if (f1.nonreport == 1 & nonreport ~= 1) | (l1.nonreport == 1 & nonreport ~= 1);
gen qdiff = qdate - qdate[_n-1] if tlidnum == tlidnum[_n-1];
gen minbaldiff = minbal - minbal[_n-1] if tlidnum == tlidnum[_n-1] & qdiff > 1;
gen maxbaldiff = maxbal - maxbal[_n-1] if tlidnum == tlidnum[_n-1] & qdiff > 1;

gen diff1q_imp = maxbaldiff / qdiff;

gen spelllength = qdiff - 1 if qdiff > 1;

keep if diff1q_imp ~= .;
keep tlidnum qdate diff1q_imp;
sort tlidnum qdate;

save ../tmp_data/imputed_balance_changes_`file'.dta, replace;

restore;

sort tlidnum qdate;
merge 1:1 tlidnum qdate using ../tmp_data/imputed_balance_changes_`file'.dta;
drop _merge;

gen bal_imp = maxbal;
gen bal_imp_prev = maxbal;
gen bal_imp_next = maxbal;
gsort tlidnum -qdate;

forvalues i = 1/50 {; 
  replace bal_imp = bal_imp[_n-1] - diff1q_imp[_n-`i'] if bal_imp==. & diff1q_imp[_n-`i']~=.;
};

replace bal_imp_next = bal_imp_next[_n-1] if bal_imp_next==. & bal_imp_next[_n-1]~=.;
gsort tlidnum qdate;
replace bal_imp_prev = bal_imp_prev[_n-1] if bal_imp_prev==. & bal_imp_prev[_n-1]~=.;

gsort tlidnum qdate;
replace cid = cid[_n-1] if cid=="" & tlidnum == tlidnum[_n-1];
gsort tlidnum -qdate;
replace cid = cid[_n-1] if cid=="" & tlidnum == tlidnum[_n-1];

count if minbal == 0;
count if maxbal == 0;

drop if minbal==0 & minpmt==0;

gen nummtg = 1;

collapse (sum) nummtg nonreport bal_imp bal_imp_next bal_imp_prev, by(cid qdate) fast;
sort cid qdate;

compress;
save ../tmp_data/mortgage_tl_`file'_imputedbals.dta, replace;
};



* ANalyze tradeline data;
*  important to show that mortgages dissappearing do not show up as charge offs;

use ../raw_data/mortgage_tl_preskatrina_hadmtg.dta;

tab narrativecode1;
tab narrativecode2;

* Natural disaster flag;
gen disaster = 0;
replace disaster = 1 if narrativecode1 == "34";
replace disaster = 1 if narrativecode2 == "034";

* Account closed by lender;
gen acctclosedl = 0;
replace acctclosedl = 1 if narrativecode1 == "65";
replace acctclosedl = 1 if narrativecode2 == "065";

* Account closed by borrower;
gen acctclosedb = 0;
replace acctclosedb = 1 if narrativecode1 == "66";
replace acctclosedb = 1 if narrativecode2 == "066";
replace acctclosedb = 1 if narrativecode1 == "168";
replace acctclosedb = 1 if narrativecode2 == "168";

* Charge off;
gen acctclosedco = 0;
replace acctclosedco = 1 if narrativecode1 == "67";
replace acctclosedco = 1 if narrativecode2 == "067";

* Closed or paid account / zero balance;
gen acctclosedu = 0;
replace acctclosedu = 1 if narrativecode1 == "158";
replace acctclosedu = 1 if narrativecode2 == "158";

gen nummtgacct = 1;

collapse (max) nummtgacct disaster acctclosed*, by(cid qtr) fast;
gen qdate = yq(year(qtr), quarter(qtr));
format qdate %tq;

sort cid qdate;
save ../tmp_data/mortgage_tradeline_aggregated_to_cid.dta, replace;




use ../raw_data/ipums_2000_new_orleans_age_and_mortgage_questions.dta;
keep if relate==1;
gen age_bin = 1 if age <= 24;
replace age_bin = 2 if age >= 25 & age <= 34;
replace age_bin = 3 if age >= 35 & age <= 44;
replace age_bin = 4 if age >= 45 & age <= 54;
replace age_bin = 5 if age >= 55 & age <= 64;
replace age_bin = 6 if age >= 65 & age ~=.;

tab2 age_bin ownershpd if (ownershpd==12 | ownershpd==21 | ownershpd==22) [fw=perwt], row;
clear;

use ../raw_data/census2000_blockgroups_la_ownerocchu_variables.dta;
merge 1:1 bg_str using ../raw_data/census2000_blockgroups_la_mortgage_variables.dta;

gen tothu = fv9001;
gen oounits = fw2001+ fw2002+ fw2003+ fw2004+ fw2005+ fw2006+ fw2007;
gen oorate = oounits / tothu;
gen mtghu = g81001;
gen oonomtghu = g81002;
gen mtgrate = mtghu / tothu;

keep bg_str tothu oounits oorate mtghu oonomtghu mtgrate;
sort bg_str;
save ../tmp_data/census2000_blockgroups_la_mortgage_variables.dta, replace;


use ../raw_data/census2000_blocks_la_placenm.dta;

count if flooddepthcoverage == 0 & placenm == "New Orleans city";
* 1207 blocks not covered by flood map but in the city of New Orleans;
count if fxs001==0 & flooddepthcoverage == 0 & placenm == "New Orleans city";
* 449 of those blocks have no inhabitants;

* keep the blocks that do have population;
keep if flooddepthcoverage == 0 & placenm == "New Orleans city";
keep block_str fxs001;
sort block_str;
* We will use this set of blocks to map and see if they are all in Algiers.  If so we can add them as controls;
save ../tmp_data/blocks_in_new_orleans_not_in_flood_map.dta, replace;

* keep only Algiers blocks.  Drop Bayou Sauvage National Wildlife Refuge;
gen tract = substr(block_str, 6, 6);
destring tract, replace;
keep if tract <= 614;
count; 
keep block_str;
sort block_str;
gen algiers_block = 1;
save ../tmp_data/algiers_blocks.dta, replace;
clear;


use ../raw_data/census2000_blocks_la_placenm.dta;

sort block_str;
merge 1:1 block_str using ../tmp_data/algiers_blocks.dta;
tab _merge;

replace flooddepthcoverage = 1 if algiers_block == 1;

table flooddepthcoverage if placenm == "New Orleans city", c(sum fxs001);

* Create zip list for merging in home core logic zip HPI;

keep if flooddepthcoverage == 1;
drop _merge;

sort block_str;
merge 1:1 block_str using ../tmp_data/block_zip_mp_2000.dta;

* blocks that are missing zips all have zero population;
sum fxs001 if _merge == 1;

drop if zcta5=="";
sort zcta5;
drop if zcta5 == zcta5[_n-1];

keep zcta5;
count;

sort zcta5;
save ../tmp_data/flood_depth_coverage_zip_list.dta, replace;



* Create CID list used to get data for people that have ever lived in the flood depth coverage area;

use ../raw_data/la_all_cid.dta;
gen block_str = "22" + county_code + census_tract + census_block;
sort block_str;

merge m:1 block_str using ../raw_data/census2000_blocks_la_placenm.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

gen qdate = yq(year(qtr), quarter(qtr));
format qdate %tq;

tab qdate if placenm == "New Orleans city";
tab qdate if flooddepthcoverage == 1;

keep  if flooddepthcoverage == 1;
sort cid;
drop if cid==cid[_n-1];
keep cid;
count;
outsheet cid using ../raw_data/all_cid_ever_in_flooddepth_covered_area.csv, comma replace noquote;
clear;


* Create CID list used to get data for people that have ever lived in the flood depth coverage area;
*  Also include Algiers neighborhood which is in New Orleans but was not flooded and thus not in the;
*  reported flood depth data;

use ../raw_data/la_all_cid.dta;
gen block_str = "22" + county_code + census_tract + census_block;
sort block_str;

merge m:1 block_str using ../raw_data/census2000_blocks_la_placenm.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

sort block_str;
merge m:1 block_str using ../tmp_data/algiers_blocks.dta;
drop if _merge == 2;
drop _merge;

gen qdate = yq(year(qtr), quarter(qtr));
format qdate %tq;

tab qdate if placenm == "New Orleans city";
tab qdate if flooddepthcoverage == 1;
tab qdate if algiers == 1;
tab qdate if flooddepthcoverage == 1 | algiers_block == 1;

keep  if flooddepthcoverage == 1 | algiers_block == 1;
sort cid;
drop if cid==cid[_n-1];
keep cid;
count;
outsheet cid using ../raw_data/all_cid_ever_in_flooddepth_covered_area_plus_algiers.csv, comma replace noquote;
clear;



use ../raw_data/census2000_blck_grp.dta;
sort state county tract blck_grp;
merge 1:1 state county tract blck_grp using ../raw_data/census2000_blck_grp_vars.dta;
tab _merge;
drop _merge;

gen bg_str = string(state, "%02.0f") + string(county, "%03.0f") + string(tract, "%06.0f") + string(blck_grp, "%01.0f");
drop state county tract blck_grp;
compress;
sort bg_str;


// convert to 2005 dollars;
replace medhhinc = medhhinc * 194.5 / 169.933;
replace medoohval = medoohval * 194.5 / 169.933;
drop lmedhhinc lmedoohval;
gen lmedhhinc = log(medhhinc);
gen lmedoohval = log(medoohval);

save ../tmp_data/census2000_blck_grp.dta, replace;


use ../raw_data/nola_w_algiers_flood_risk_1999_fema.dta;
rename STFID block_str;

sort block_str;
merge 1:1 block_str using ../tmp_data/algiers_blocks.dta;
tab _merge;
drop _merge;

rename block_str STFID;
sort STFID;
merge 1:1 STFID using ../raw_data/katrina_flood_depth_noaa.dta;
tab _merge;
drop if _merge == 1 & algiers_block ~= 1;
drop _merge;

gen bg_str = substr(STFID, 1, 12);
sort bg_str;
merge m:1 bg_str using ../tmp_data/census2000_blck_grp.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

* set all algiers block to 0 flood depth;
foreach day in 0831 0903 0905 0908 0914 09142 0915 09152 {;
forvalues d = 0/31 {;
  replace areadepth`d'd`day' = 0 if algiers_block == 1;
};
};

* create mean flood depth by block on each day;

foreach day in 0831 0903 0905 0908 0914 09142 0915 09152 {;
forvalues d = 0/31 {;
  gen propdepth`d'd`day' = areadepth`d'd`day' / area;
};

sum propdepth*;

gen meandepthd`day' = propdepth0d`day' * 0.25;
forvalues d = 1/31 {;
  replace meandepthd`day' = meandepthd`day' + (propdepth`d'd`day' * `d');
};
};

sum meandepth*;

egen maxmeandepth = rowmax(meandepthd0831 meandepthd0903 meandepthd0905 meandepthd0908 meandepthd0914 meandepthd09142 meandepthd0915 meandepthd09152);

gen propa = areazoneA / area;
gen propx500 = areazoneX500 / area;
gen propundes = areazoneUNDES / area;

count;

count if propa >= 0.99;
replace propa = 0 if propa < 0.01;
replace propa = 1 if propa > 0.99 & propa ~= .;

count if propx500 >= 0.99;
replace propx500 = 0 if propx500 < 0.01;
replace propx500 = 1 if propx500 > 0.99 & propx500 ~= .;

sum propundes;
drop propundes;

sum maxmeandepth if propa == 1, d;
sum maxmeandepth if propx500 == 1, d;


sort STFID;
merge 1:1 STFID using ../raw_data/mean_min_max_elevation_by_block_new_orleans_w_algiers.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

rename STFID block_str;

rename pop bgpop;

keep block_str maxmeandepth meandepth* propa propx500 area bgpop f65p fhisp faa medoohval lmedoohval lmedhhinc fforborn povrate fmin fba foo meanelev minelev maxelev;

sort block_str;

xtile qdepth = maxmeandepth if maxmeandepth > 0, nq(4);
replace qdepth = 0 if maxmeandepth==0;

reg maxmeandepth meanelev propa, robust;
reg maxmeandepth meanelev minelev maxelev propa, robust;

tab qdepth;
table qdepth, c(mean maxmeandepth mean meanelev mean propa mean povrate mean faa);

sort block_str;
save ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta, replace;


keep block_str;
gen depthcoverage_block = 1;
sort block_str;
save ../tmp_data/depthcoverage_blocks.dta, replace;


use ../tmp_data/depthcoverage_blocks.dta;
gen bg_str = substr(block_str, 1, 12);
sort bg_str;
drop if bg_str == bg_str[_n-1];
keep bg_str;
sort bg_str;
save ../tmp_data/depthcoverage_blockgroups.dta, replace;


use ../tmp_data/depthcoverage_blocks.dta;
gen tract_str = substr(block_str, 1, 11);
sort tract_str;
drop if tract_str == tract_str[_n-1];
keep tract_str;
sort tract_str;
save ../tmp_data/depthcoverage_tracts.dta, replace;


use ../tmp_data/census2000_blockgroups_la_mortgage_variables.dta;

sort bg_str;
merge 1:1 bg_str using ../tmp_data/depthcoverage_blockgroups.dta;
keep if _merge == 3;
drop _merge;

gen oonomtghu_per_hu = oonomtghu / tothu;

* Can use only block groups with a ratio of less than 20 or 10 percent of housing uints that are owner occupied but have no mortgage;
count;
count if oonomtghu_per_hu < 0.2;
count if oonomtghu_per_hu < 0.1;

compress;
keep bg_str oonomtghu_per_hu;
sort bg_str;
save ../tmp_data/bg_oonomtg_ratio.dta, replace;




* Use the extract for all cids ever in flood coverage area including algiers with crtr_attr vars 1 to 88;

use ../raw_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_1_88_follow.dta;
gen qdate = qofd(qtr);
format qdate %tq;

* Merge in state fips codes;

sort state;
merge m:1 state using ../raw_data/state_fips.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

* Current block of residence;
gen block_str = string(state_code, "%02.0f") + county_code + census_tract + census_block;

* Create block of residence in 2005q3 (Katrina);
gen block_str_2005q3 = block_str if qdate == yq(2005, 3);
gsort cid qdate;
replace block_str_2005q3 = block_str_2005q3[_n-1] if cid==cid[_n-1] & block_str_2005q3=="" & block_str_2005q3[_n-1]~="";
gsort cid -qdate;
replace block_str_2005q3 = block_str_2005q3[_n-1] if cid==cid[_n-1] & block_str_2005q3=="" & block_str_2005q3[_n-1]~="";

* Merge in flood depth data based on block of residence in 2005q3;
rename block_str block_str_tmp;
rename block_str_2005q3 block_str;
sort block_str;
merge m:1 block_str using ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta;
tab _merge;
drop if _merge == 2;
gen depthcoverage_block = (_merge == 3);
drop _merge;

gen bg_str = substr(block_str, 1, 12);
sort bg_str;
merge m:1 bg_str using ../tmp_data/bg_oonomtg_ratio.dta;
drop if _merge == 2;
drop _merge;

sort block_str;
merge m:1 block_str using ../raw_data/la_census2000_block_propaa.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

gen tract_str = substr(block_str, 1, 11);
sort tract_str;
merge m:1 tract_str using ../tmp_data/katrina_tractmeans.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

drop tract_str;

rename bg_str bg_str_2005q3;

rename block_str block_str_2005q3;
rename block_str_tmp block_str;

replace block_str_2005q3 = "" if (depthcoverage_block ~= 1);

gen pres_during_katrina = (block_str_2005q3 ~= "" & depthcoverage_block == 1);
drop depthcoverage_block;

sort block_str;
merge m:1 block_str using ../tmp_data/depthcoverage_blocks.dta;
tab _merge;
drop if _merge == 2;
drop _merge;


egen ncid = group(cid);
tsset ncid qdate;

gen tmp_qdate = qdate if (depthcoverage_block == 1);
bys cid: egen last_depthcoverage_quarter = max(tmp_qdate);
replace last_depthcoverage_quarter = . if pres_during_katrina == 1;
format last_depthcoverage_quarter %tq;
gen last_depthcoverage_block = block_str if qdate == last_depthcoverage_quarter;

gen tmp_left_before_katrina = (last_depthcoverage_quarter < yq(2005,3));
bys cid: egen left_before_katrina = max(tmp_left_before_katrina);

gsort cid -qdate;
replace last_depthcoverage_block = last_depthcoverage_block[_n-1] if cid==cid[_n-1] & last_depthcoverage_block=="" & last_depthcoverage_block[_n-1]~="";
gsort cid qdate;
replace last_depthcoverage_block = last_depthcoverage_block[_n-1] if cid==cid[_n-1] & last_depthcoverage_block=="" & last_depthcoverage_block[_n-1]~="";

replace block_str_2005q3 = last_depthcoverage_block if block_str_2005q3 == "" & left_before_katrina == 1;

rename block_str block_str_tmp;
rename last_depthcoverage_block block_str;
sort block_str;
merge m:1 block_str using ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta, update;
tab _merge;
drop if _merge == 2;
drop _merge;
rename block_str last_depthcoverage_block;
rename block_str_tmp block_str;

gsort cid qdate;

do variable_creation_num.do;
do variable_creation_gt1.do;

drop if dup_cid_flag_d == 2;

compress;
sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_1_88_follow.dta, replace;
clear;



use ../raw_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_89_end_follow.dta;
gen qdate = qofd(qtr);
format qdate %tq;

keep if primary_flag_d == "1";
sort cid qdate;
count if cid==cid[_n-1] & qdate==qdate[_n-1];
drop if cid==cid[_n-1] & qdate==qdate[_n-1];

compress;
sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_89_end_follow.dta, replace;


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_1_88_follow.dta;

merge 1:1 cid qdate using ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_crtr_89_end_follow.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

sort qdate;
merge m:1 qdate using ../raw_data/cpi_allitems_urban_quarterly_not_sa.dta;
drop if _merge == 2;
drop _merge;

do variable_creation_bal.do;

* Use Correct Student Loan Balance Variable;
drop bal_stdln_tot;

sort cid qtr;
merge 1:1 cid qtr using ../raw_data/correct_student_loan_balance_var.dta;
tab _merge;
drop if qdate == .;
drop _merge;

replace bal_stdln_tot = 0 if bal_stdln_tot == . & num_all_tot ~= .;
replace bal_stdln_tot = . if qdate < yq(2004,3);

* Put balance variables into real terms (year 2005q2 dollars);
foreach acct in all autof autob bankc consf fmrtg helin helre retal stdln other auto bcret home exhome {;
  foreach del in tot 90 {;
    replace bal_`acct'_`del' = bal_`acct'_`del' * 194.5 / cpi;
  };
};

compress;

sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow.dta, replace;




* create datasets for Baton Rouge, Memphis, and St Louis;

use ../raw_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_1_88_follow.dta;

gen qdate = qofd(qtr);
format qdate %tq;

sort state;
merge m:1 state using ../raw_data/state_fips.dta;
tab _merge;
drop if _merge == 2;
drop _merge;
gen block_str = string(state_code, "%02.0f") + county_code + census_tract + census_block;
gen block_str_2005q3 = block_str if qdate == yq(2005, 3);

gsort cid qdate;
replace block_str_2005q3 = block_str_2005q3[_n-1] if cid==cid[_n-1] & block_str_2005q3=="" & block_str_2005q3[_n-1]~="";
gsort cid -qdate;
replace block_str_2005q3 = block_str_2005q3[_n-1] if cid==cid[_n-1] & block_str_2005q3=="" & block_str_2005q3[_n-1]~="";

rename block_str block_str_tmp;
rename block_str_2005q3 block_str;

sort block_str;
merge m:1 block_str using ../raw_data/batonrouge_memphis_stlouis_blocks.dta;
drop if _merge == 2;
drop _merge;

rename block_str block_str_2005q3;
rename block_str_tmp block_str ;


gsort cid qdate;

do variable_creation_num.do;
do variable_creation_gt1.do;

compress;
sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_1_88_follow.dta, replace;
clear;



use ../raw_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_89_end_follow.dta;
gen qdate = qofd(qtr);
format qdate %tq;

compress;
sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_89_end_follow.dta, replace;


use ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_1_88_follow.dta;

merge 1:1 cid qdate using ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_crtr_89_end_follow.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

sort qdate;
merge m:1 qdate using ../raw_data/cpi_allitems_urban_quarterly_not_sa.dta;
drop if _merge == 2;
drop _merge;

do variable_creation_bal.do;

* Make sure not to use bad Student Loan Balance Variable;
replace bal_stdln_tot = .;


* Put balance variables into real terms (year 2005q2 dollars);
foreach acct in all autof autob bankc consf fmrtg helin helre retal stdln other auto bcret home exhome {;
  foreach del in tot 90 {;
    replace bal_`acct'_`del' = bal_`acct'_`del' * 194.5 / cpi;
  };
};

compress;
sort cid qdate;
save ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_follow.dta, replace;







use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow.dta;

* want people living in depth coverage area in 2000;

keep if depthcoverage_block == 1;
gen bg_str = substr(block_str, 1, 12);
sort bg_str;

keep if qdate == yq(2000, 1);

gen eqfobs = 1;
collapse (sum) eqfobs gt1_home_tot, by(bg_str) fast;
sort bg_str;

replace eqfobs = 20*eqfobs;
replace gt1_home_tot = 20*gt1_home_tot;

merge m:1 bg_str using ../tmp_data/census2000_blockgroups_la_mortgage_variables.dta;
drop if _merge == 2;
drop _merge;

* number of mortgage holders in equifax is correlated with number of housing units with a mortgage in census;
corr gt1_home_tot mtghu;

clear;

    









* Get control cities ready to append into New Orleans data;

use ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_follow.dta;

sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/mortgage_tl_pres_batonrouge_memphis_stlouis_2005q3_imputedbals.dta;
drop if _merge == 2;
gen mtg_exists = (_merge == 3);
drop _merge;

preserve;
keep if (qdate>=yq(2002,3) & qdate<=yq(2008,3));
sort cid qdate;
by cid: gen numobs0208 = _N;
gen fullsample0208 = 1 if numobs0208 == 25;
keep cid qdate fullsample0208;
sort cid qdate;
save ../tmp_data/fullsample0208_indicator_controlcities.dta, replace;
restore;

sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/fullsample0208_indicator_controlcities.dta;
tab _merge;
drop _merge;

save ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_follow_imputed.dta, replace;









use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow.dta, clear;


sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/mortgage_tl_depthcoverage_ever_imputedbals.dta;
drop if _merge == 2;
gen mtg_exists = (_merge == 3);
drop _merge;

gen tract_str = substr(block_str_2005q3, 1, 11);
rename propaa block_propaa;
sort tract_str;
merge m:1 tract_str using ../raw_data/la_census2000_tract_propaa.dta;
tab _merge;
drop if _merge == 2;
drop _merge;
rename propaa tract_propaa;
rename block_propaa propaa;
rename tract_str tract_str_2005q3;

rename block_str block_str_tmp; 
rename block_str_2005q3 block_str;
sort block_str;
merge m:1 block_str using ../tmp_data/block_zip_mp_2000.dta;

rename block_str block_str_2005q3;
rename block_str_tmp block_str;

tab _merge if pres_during_katrina==1; 
drop if _merge == 2;
drop _merge;

gen sfha = "S" if propa >= 0.5 & propa~=.;
replace sfha = "N" if sfha == "" & propx500 >= 0.5 & propx500~=.;
replace sfha = "U" if sfha == "" & propa~=. & propx500~=.;

tab sfha;

sort zcta5;

merge m:1 zcta5 sfha using ../tmp_data/claims_2005.dta;
drop if _merge == 2;
drop _merge;

merge m:1 zcta5 sfha using ../tmp_data/policies_in_force_2004.dta;
drop if _merge == 2;
drop _merge;

merge m:1 zcta5 using ../raw_data/ccp_nfip_census.dta;
drop if _merge == 2;
drop _merge;




egen tmp_zip_zone_bal_home = sum(bal_home_tot) if qdate==yq(2005,3), by(zcta5 sfha);
replace tmp_zip_zone_bal_home = 20 * tmp_zip_zone_bal_home;
egen zip_zone_bal_home = min(tmp_zip_zone_bal_home), by(cid);
drop tmp_zip_zone_bal_home;
gen shr_bal_claim = claim_dollars / zip_zone_bal_home; 

egen tmp_zip_zone_gt1_home = sum(gt1_home_tot) if qdate==yq(2005,3), by(zcta5 sfha);
replace tmp_zip_zone_gt1_home = 20 * tmp_zip_zone_gt1_home;
egen zip_zone_gt1_home = min(tmp_zip_zone_gt1_home), by(cid);
drop tmp_zip_zone_gt1_home;
gen shr_num_claim = claims / zip_zone_gt1_home; 


gen state_str = substr(block_str, 1, 2);
gen county_str = substr(block_str, 1, 5);

drop ncid;
egen ncid = group(cid);
tsset ncid qdate;

gen nola = (depthcoverage_block == 1);
gen la = (substr(block_str, 1, 2)=="22");
gen nocsa = 0;
replace nocsa = 1 if (county_str == "22051" | county_str == "22071" | county_str == "22075" | county_str == "22087" | county_str == "22089" | county_str == "22093" | county_str == "22095" | county_str == "22103" | county_str == "22117" | county_str == "22105" | county_str == "29109");


* create variable for how many years you lived in NO prior to Katrina;

* keep out people who never lived in NO prior or during Katrina;
drop if left_before_katrina == 0 & pres_during_katrina==0;

tsset ncid qdate;


* create did you migrate leave NO for at least a quarter starting in quarter of move;
gen leftgeq1q = 0 if nola~=. & l1.nola==1;
replace leftgeq1q = 1 if nola==0 & l1.nola==1;

* create did you leave NO for at least a year starting in quarter of move;
gen leftgeq1yr = 0 if nola~=. & l1.nola==1 & f1.nola~=. & f2.nola~=. & f3.nola~=.;
replace leftgeq1yr = 1 if nola==0 & l1.nola==1 & f1.nola==0 & f2.nola==0 & f3.nola==0;

* create did you migrate leave NO for at least two years starting in quarter of move;
gen leftgeq2yr = 0 if nola~=. & l1.nola==1 & f1.nola~=. & f2.nola~=. & f3.nola~=. & f4.nola~=. & f5.nola~=. & f6.nola~=. & f7.nola~=.;
replace leftgeq2yr = 1 if nola==0 & l1.nola==1 & f1.nola==0 & f2.nola==0 & f3.nola==0 & f4.nola==0 & f5.nola==0 & f6.nola==0 & f7.nola==0;

* create did you migrate leave NO for at least 3 years starting in quarter of move;
gen leftgeq3yr = 0 if nola~=. & l1.nola==1 & f1.nola~=. & f2.nola~=. & f3.nola~=. & f4.nola~=. & f5.nola~=. & f6.nola~=. & f7.nola~=. & f8.nola~=. & f9.nola~=. & f10.nola~=. & f11.nola~=.;
replace leftgeq3yr = 1 if nola==0 & l1.nola==1 & f1.nola==0 & f2.nola==0 & f3.nola==0 & f4.nola==0 & f5.nola==0 & f6.nola==0 & f7.nola==0 & f8.nola==0 & f9.nola==0 & f10.nola==0 & f11.nola==0;

* create did you migrate leave NO for at least 4 years starting in quarter of move;
gen leftgeq4yr = 0 if nola~=. & l1.nola==1 & f1.nola~=. & f2.nola~=. & f3.nola~=. & f4.nola~=. & f5.nola~=. & f6.nola~=. & f7.nola~=. & f8.nola~=. & f9.nola~=. & f10.nola~=. & f11.nola~=. & f12.nola~=. & f13.nola~=. & f14.nola~=. & f15.nola~=.;
replace leftgeq4yr = 1 if nola==0 & l1.nola==1 & f1.nola==0 & f2.nola==0 & f3.nola==0 & f4.nola==0 & f5.nola==0 & f6.nola==0 & f7.nola==0 & f8.nola==0 & f9.nola==0 & f10.nola==0 & f11.nola==0 & f12.nola==0 & f13.nola==0 & f14.nola==0 & f15.nola==0;



* create did you migrate leave NO CSA for at least a quarter starting in quarter of move;
gen leftcsageq1q = 0 if nocsa~=. & l1.nocsa==1;
replace leftcsageq1q = 1 if nocsa==0 & l1.nocsa==1;

* create did you leave NO CSA for at least a year starting in quarter of move;
gen leftcsageq1yr = 0 if nocsa~=. & l1.nocsa==1 & f1.nocsa~=. & f2.nocsa~=. & f3.nocsa~=.;
replace leftcsageq1yr = 1 if nocsa==0 & l1.nocsa==1 & f1.nocsa==0 & f2.nocsa==0 & f3.nocsa==0;

* create did you migrate leave NO CSA for at least two years starting in quarter of move;
gen leftcsageq2yr = 0 if nocsa~=. & l1.nocsa==1 & f1.nocsa~=. & f2.nocsa~=. & f3.nocsa~=. & f4.nocsa~=. & f5.nocsa~=. & f6.nocsa~=. & f7.nocsa~=.;
replace leftcsageq2yr = 1 if nocsa==0 & l1.nocsa==1 & f1.nocsa==0 & f2.nocsa==0 & f3.nocsa==0 & f4.nocsa==0 & f5.nocsa==0 & f6.nocsa==0 & f7.nocsa==0;

* create did you migrate leave NO CSA for at least 3 years starting in quarter of move;
gen leftcsageq3yr = 0 if nocsa~=. & l1.nocsa==1 & f1.nocsa~=. & f2.nocsa~=. & f3.nocsa~=. & f4.nocsa~=. & f5.nocsa~=. & f6.nocsa~=. & f7.nocsa~=. & f8.nocsa~=. & f9.nocsa~=. & f10.nocsa~=. & f11.nocsa~=.;
replace leftcsageq3yr = 1 if nocsa==0 & l1.nocsa==1 & f1.nocsa==0 & f2.nocsa==0 & f3.nocsa==0 & f4.nocsa==0 & f5.nocsa==0 & f6.nocsa==0 & f7.nocsa==0 & f8.nocsa==0 & f9.nocsa==0 & f10.nocsa==0 & f11.nocsa==0;

* create did you migrate leave NO CSA for at least 4 years starting in quarter of move;
gen leftcsageq4yr = 0 if nocsa~=. & l1.nocsa==1 & f1.nocsa~=. & f2.nocsa~=. & f3.nocsa~=. & f4.nocsa~=. & f5.nocsa~=. & f6.nocsa~=. & f7.nocsa~=. & f8.nocsa~=. & f9.nocsa~=. & f10.nocsa~=. & f11.nocsa~=. & f12.nocsa~=. & f13.nocsa~=. & f14.nocsa~=. & f15.nocsa~=.;
replace leftcsageq4yr = 1 if nocsa==0 & l1.nocsa==1 & f1.nocsa==0 & f2.nocsa==0 & f3.nocsa==0 & f4.nocsa==0 & f5.nocsa==0 & f6.nocsa==0 & f7.nocsa==0 & f8.nocsa==0 & f9.nocsa==0 & f10.nocsa==0 & f11.nocsa==0 & f12.nocsa==0 & f13.nocsa==0 & f14.nocsa==0 & f15.nocsa==0;



gen gt1_home_tot_imp = gt1_home_tot;
replace gt1_home_tot_imp = 1 if (nonreport>0 & nonreport~=.) & num_all_tot ~=. ;

gen bal_home_tot_imp = bal_home_tot;
replace bal_home_tot_imp = bal_imp if (nonreport>0 & nonreport~=.) & num_all_tot ~=. ;

gen bal_home_tot_imp_next = bal_home_tot;
replace bal_home_tot_imp_next = bal_imp_next if (nonreport>0 & nonreport~=.) & num_all_tot ~=. ;

gen bal_home_tot_imp_prev = bal_home_tot;
replace bal_home_tot_imp_prev = bal_imp_prev if (nonreport>0 & nonreport~=.) & num_all_tot ~=. ;

gen bal_all_tot_imp = bal_all_tot - bal_home_tot + bal_home_tot_imp;


* compare mortgage holders and non-mortgage holders in deeply flooded areas;
gen had_mtg_tmp = 0;
replace had_mtg_tmp = 1 if qdate == yq(2005,3) & gt1_home_tot == 1;
egen had_mtg = max(had_mtg_tmp), by(cid);
drop had_mtg_tmp;

* variable to indicate having an auto loan;
gen had_auto_tmp = 0;
replace had_auto_tmp = 1 if qdate == yq(2005,3) & gt1_auto_tot == 1;
egen had_auto = max(had_auto_tmp), by(cid);
drop had_auto_tmp;

gen year = year( dofq(qdate) );

sort cid qdate;
by cid: gen numobs = _N;
gen fullsample = 1 if numobs == 58;


preserve;
keep if (qdate>=yq(2002,3) & qdate<=yq(2008,3));
sort cid qdate;
by cid: gen numobs0208 = _N;
gen fullsample0208 = 1 if numobs0208 == 25;
keep cid qdate fullsample0208;
sort cid qdate;
save ../tmp_data/fullsample0208_indicator.dta, replace;
restore;

sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/fullsample0208_indicator.dta;
tab _merge;
drop _merge;

gen age = year(qtr) - birthyear if birthyear ~= 0;
gen age_sq = age^2;
gen age_cu = age^3;



* Create possible credit constraint indicator variables;

gen bcret_ratio = bal_bcret_tot / hic_bcret_tot;
sum bcret_ratio if qdate==yq(2005,2) & qdepth>=0 & pres_during_katrina ==1 & fullsample0208==1 & num_all_tot~=., d;

* Did having a CC help people smooth;

gen had_cc_tmp = 0;
replace had_cc_tmp = 1 if qdate == yq(2005,3) & gt1_bcret_tot == 1;
egen had_cc = max(had_cc_tmp), by(cid);
drop had_cc_tmp;

gen cc_const_tmp = 0 if qdate == yq(2005,3) & gt1_bcret_tot == 1;
replace cc_const_tmp = 1 if  qdate == yq(2005,3) & gt1_bcret_tot == 1 & bcret_ratio >= 0.75 & bcret_ratio ~= .;
egen cc_const = max(cc_const_tmp), by(cid);
drop cc_const_tmp;


gen bcret_avail_bal = hic_bcret_tot - bal_bcret_tot;
replace bcret_avail_bal = 0 if bcret_avail_bal < 0;
sum bcret_avail_bal if qdate==yq(2005,2) & qdepth>=0 & pres_during_katrina ==1 & fullsample0208==1 & num_all_tot~=. & had_cc==1, d;

xtile pct_bcret_avail_bal = bcret_avail_bal if qdate==yq(2005,2) & qdepth>=0 & pres_during_katrina ==1 & fullsample0208==1 & num_all_tot~=. & had_cc==1, nq(100);

* what share of people in the most flooded blocks were credit constrained in the quarter after Katrina?;

gen maxed_out= 0 if bcret_ratio ~= .;
replace maxed_out = 1 if bcret_ratio >= 1 & bcret_ratio ~= .;


sort cid qdate;
gen f4block_str = block_str[_n+4] if cid==cid[_n+4];
gen f12block_str = block_str[_n+12] if cid==cid[_n+12];

gen sameblock1yr = (f4block_str == block_str);
gen sameblock3yr = (f12block_str == block_str);


tsset ncid qdate;
gen nola1yr = (f4.nola == 1);
gen nola3yr = (f12.nola == 1);
gen nocsa1yr = (f4.nocsa == 1);
gen nocsa3yr = (f12.nocsa == 1);

gen bal_home_tot_imp_had_mtg = bal_home_tot_imp if had_mtg == 1;
gen gt1_home_tot_imp_had_mtg = gt1_home_tot_imp if had_mtg == 1;
 
gen shrrpt = 0;
replace shrrpt = 1 if (nonreport==0 | nonreport==.);


gen nola_x_maxmeandepth = nola * maxmeandepth;

gen post = ( qdate > yq(2005, 3) );

gen flooded = ( maxmeandepth > 0 );
gen flooded_x_p = flooded * post;

gen floodedq0 = (qdepth == 0);
gen floodedq1 = (qdepth == 1);
gen floodedq2 = (qdepth == 2);
gen floodedq3 = (qdepth == 3);
gen floodedq4 = (qdepth == 4);

gen floodedq0_x_p = floodedq0 * post;
gen floodedq1_x_p = floodedq1 * post;
gen floodedq2_x_p = floodedq2 * post;
gen floodedq3_x_p = floodedq3 * post;
gen floodedq4_x_p = floodedq4 * post;





gen tmp_riskscore_2005q2 = riskscore if yq(2005, 2);
bys cid: egen riskscore_2005q2 = min(tmp_riskscore_2005q2);
drop tmp_riskscore_2005q2;

gen tmp_age_2005q2 = age if yq(2005, 2);
bys cid: egen age_2005q2 = min(tmp_age_2005q2);
drop tmp_age_2005q2;

gen age_2005q2_sq = age_2005q2^2;
gen age_2005q2_cu = age_2005q2^3;


gen tmp_bal_all_tot_2005q2 = bal_all_tot if yq(2005, 2);
bys cid: egen bal_all_tot_2005q2 = min(tmp_bal_all_tot_2005q2);
drop tmp_bal_all_tot_2005q2;

gen meanelev_sq  = meanelev^2;
gen maxelev_sq = maxelev^2;
gen minelev_sq = minelev^2;

gen meanelev_cub = meanelev^3;
gen maxelev_cub = maxelev^3;
gen minelev_cub = minelev^3;

gen propa_sq = propa^2;
gen propa_cu = propa^3;

gen propa_x_elev = propa * meanelev;


gen maxmeandepth_x_2006q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2006q3 = maxmeandepth if qdate == yq(2006, 3);

gen maxmeandepth_x_2007q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2007q3 = maxmeandepth if qdate == yq(2007, 3);

gen maxmeandepth_x_2008q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2008q3 = maxmeandepth if qdate == yq(2008, 3);

gen dpropa = (propa > 0.99);



	gen d2001q1 = (qdate == yq(2001, 1));
	gen d2001q2 = (qdate == yq(2001, 2));
	gen d2001q3 = (qdate == yq(2001, 3));
	gen d2001q4 = (qdate == yq(2001, 4));
	gen d2002q1 = (qdate == yq(2002, 1));
	gen d2002q2 = (qdate == yq(2002, 2));
	gen d2002q3 = (qdate == yq(2002, 3));
	gen d2002q4 = (qdate == yq(2002, 4));
	gen d2003q1 = (qdate == yq(2003, 1));
	gen d2003q2 = (qdate == yq(2003, 2));
	gen d2003q3 = (qdate == yq(2003, 3));
	gen d2003q4 = (qdate == yq(2003, 4));
	gen d2004q1 = (qdate == yq(2004, 1));
	gen d2004q2 = (qdate == yq(2004, 2));
	gen d2004q3 = (qdate == yq(2004, 3));
	gen d2004q4 = (qdate == yq(2004, 4));
	gen d2005q1 = (qdate == yq(2005, 1));
	gen d2005q2 = (qdate == yq(2005, 2));
	gen d2005q3 = (qdate == yq(2005, 3));
	gen d2005q4 = (qdate == yq(2005, 4));
	gen d2006q1 = (qdate == yq(2006, 1));
	gen d2006q2 = (qdate == yq(2006, 2));
	gen d2006q3 = (qdate == yq(2006, 3));
	gen d2006q4 = (qdate == yq(2006, 4));
	gen d2007q1 = (qdate == yq(2007, 1));
	gen d2007q2 = (qdate == yq(2007, 2));
	gen d2007q3 = (qdate == yq(2007, 3));
	gen d2007q4 = (qdate == yq(2007, 4));
	gen d2008q1 = (qdate == yq(2008, 1));
	gen d2008q2 = (qdate == yq(2008, 2));
	gen d2008q3 = (qdate == yq(2008, 3));
	gen d2008q4 = (qdate == yq(2008, 4));
	gen d2009q1 = (qdate == yq(2009, 1));
	gen d2009q2 = (qdate == yq(2009, 2));
	gen d2009q3 = (qdate == yq(2009, 3));
	gen d2009q4 = (qdate == yq(2009, 4));


	* 0. Define these new variables;

	* Quartile Depth postflood variables;
	forvalues q = 0/4 {;
	gen floodedq`q'_x_2001q1 = floodedq`q'*d2001q1;
	gen floodedq`q'_x_2001q2 = floodedq`q'*d2001q2;
	gen floodedq`q'_x_2001q3 = floodedq`q'*d2001q3;
	gen floodedq`q'_x_2001q4 = floodedq`q'*d2001q4;
	gen floodedq`q'_x_2002q1 = floodedq`q'*d2002q1;
	gen floodedq`q'_x_2002q2 = floodedq`q'*d2002q2;
	gen floodedq`q'_x_2002q3 = floodedq`q'*d2002q3;
	gen floodedq`q'_x_2002q4 = floodedq`q'*d2002q4;
	gen floodedq`q'_x_2003q1 = floodedq`q'*d2003q1;
	gen floodedq`q'_x_2003q2 = floodedq`q'*d2003q2;
	gen floodedq`q'_x_2003q3 = floodedq`q'*d2003q3;
	gen floodedq`q'_x_2003q4 = floodedq`q'*d2003q4;
	gen floodedq`q'_x_2004q1 = floodedq`q'*d2004q1;
	gen floodedq`q'_x_2004q2 = floodedq`q'*d2004q2;
	gen floodedq`q'_x_2004q3 = floodedq`q'*d2004q3;
	gen floodedq`q'_x_2004q4 = floodedq`q'*d2004q4;
	gen floodedq`q'_x_2005q1 = floodedq`q'*d2005q1;
	gen floodedq`q'_x_2005q2 = floodedq`q'*d2005q2;
	gen floodedq`q'_x_2005q3 = floodedq`q'*d2005q3;
	gen floodedq`q'_x_2005q4 = floodedq`q'*d2005q4;
	gen floodedq`q'_x_2006q1 = floodedq`q'*d2006q1;
	gen floodedq`q'_x_2006q2 = floodedq`q'*d2006q2;
	gen floodedq`q'_x_2006q3 = floodedq`q'*d2006q3;
	gen floodedq`q'_x_2006q4 = floodedq`q'*d2006q4;
	gen floodedq`q'_x_2007q1 = floodedq`q'*d2007q1;
	gen floodedq`q'_x_2007q2 = floodedq`q'*d2007q2;
	gen floodedq`q'_x_2007q3 = floodedq`q'*d2007q3;
	gen floodedq`q'_x_2007q4 = floodedq`q'*d2007q4;
	gen floodedq`q'_x_2008q1 = floodedq`q'*d2008q1;
	gen floodedq`q'_x_2008q2 = floodedq`q'*d2008q2;
	gen floodedq`q'_x_2008q3 = floodedq`q'*d2008q3;
	gen floodedq`q'_x_2008q4 = floodedq`q'*d2008q4;
	gen floodedq`q'_x_2009q1 = floodedq`q'*d2009q1;
	gen floodedq`q'_x_2009q2 = floodedq`q'*d2009q2;
	gen floodedq`q'_x_2009q3 = floodedq`q'*d2009q3;
	gen floodedq`q'_x_2009q4 = floodedq`q'*d2009q4;
	};

	gen d2001 = (year(dofq(qdate)) == 2001);
	gen d2002 = (year(dofq(qdate)) == 2002);
	gen d2003 = (year(dofq(qdate)) == 2003);
	gen d2004 = (year(dofq(qdate)) == 2004);
	gen d2005 = (year(dofq(qdate)) == 2005);
	gen d2006 = (year(dofq(qdate)) == 2006);
	gen d2007 = (year(dofq(qdate)) == 2007);
	gen d2008 = (year(dofq(qdate)) == 2008);
	gen d2009 = (year(dofq(qdate)) == 2009);

	forvalues y = 2001/2009 {;
  	  forvalues q = 0/4 {;
	    gen floodedq`q'_x_`y' = floodedq`q'*d`y';
	    gen floodedq`q'_x_`y'_mtg = floodedq`q'*d`y'*had_mtg;
	  };
	};

	gen depth_x_post = maxmeandepth * post;
	forvalues y = 2001/2009 {;
	    gen depth_x_`y' = maxmeandepth*d`y';
	};
	
	
	* Census Tract by Quarter FEs;
	egen ct_q = group(qdate tract_str);







* Interaction Term: had_mtg by post flood;
gen hadmtg_x_p = post*had_mtg;

* Interaction Terms: flood quartile by had mortgage;
forvalues x = 0/4 {;
  gen floodedq`x'_x_mtg = floodedq`x'*had_mtg;
};
	
* Triple Interaction Terms;
forvalues x = 0/4 {;
  gen floodedq`x'_x_pmtg = floodedq`x'_x_p*had_mtg;
};





gen bal_home_tot_had_mtg = bal_home_tot if had_mtg == 1;

gen bal_auto_tot_had_auto = bal_auto_tot if had_auto == 1;

gen gt1_home_tot_had_mtg = gt1_home_tot if had_mtg == 1;
gen gt1_auto_tot_had_auto = gt1_auto_tot if had_auto == 1;

gen gt1_home_90_had_mtg = gt1_home_90 if had_mtg == 1;
gen gt1_auto_90_had_auto = gt1_auto_90 if had_auto == 1;

gen num_home_tot_had_mtg = num_home_tot if had_mtg == 1;


drop ncid;
egen ncid = group(cid);

tsset ncid qdate;
gen fstart = 0 if fforeclosure == 0 & l1.fforeclosure == 0;
replace fstart = 1 if fforeclosure == 1 & l1.fforeclosure == 0;
gen bstart = 0 if fbankrupt == 0 & l1.fbankrupt == 0;
replace bstart = 1 if fbankrupt == 1 & l1.fbankrupt == 0;

* Create credit demand and supply proxies;
gen inq3m = cma_attr3000;
replace inq3m = . if cma_attr3000 >= 90 & cma_attr3000 ~= .;

sort ncid qdate;
gen l1inq3m = l1.inq3m;
gen l2inq3m = l2.inq3m;
gen l3inq3m = l3.inq3m;

gen numnewacct = 0 if num_all_tot ~= . & l1.num_all_tot ~= .;
replace numnewacct = num_all_tot - l1.num_all_tot if (num_all_tot > l1.num_all_tot);


gen tmp_avail_bcret_tot = hic_bcret_tot - bal_bcret_tot if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= .;
replace tmp_avail_bcret_tot = 0 if bal_bcret_tot >= hic_bcret_tot & ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= .;
egen avail_bcret_tot = min(tmp_avail_bcret_tot), by(cid);
drop tmp_avail_bcret_tot;

sum riskscore if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= .  & num_all_tot~=., d;

gen tmp_belowmedrs = 0 if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;
replace tmp_belowmedrs = 1 if riskscore < `r(p50)' & ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;

gen tmp_below75prs = 0 if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;
replace tmp_below75prs = 1 if riskscore < `r(p75)' & ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;

gen tmp_below25prs = 0 if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;
replace tmp_below25prs = 1 if riskscore < `r(p25)' & ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & qdate==yq(2005,2) & age ~=. & lmedoohval ~= . & riskscore ~= . & num_all_tot~=.;

egen belowmedrs = min(tmp_belowmedrs), by(cid);
egen below75prs = min(tmp_below75prs), by(cid);
egen below25prs = min(tmp_below25prs), by(cid);
drop tmp_belowmedrs tmp_below75prs tmp_below25prs;

egen totfstart = sum(fstart), by (cid);
egen totbstart = sum(bstart), by (cid);

tab totfstart;
tab totbstart;

drop totfstart totbstart;


* Try Triple difference specification;
gen had_mtg_p = had_mtg * post;
gen floodedq0_had_mtg_p = floodedq0 * had_mtg * post;
gen floodedq1_had_mtg_p = floodedq1 * had_mtg * post;
gen floodedq2_had_mtg_p = floodedq2 * had_mtg * post;
gen floodedq3_had_mtg_p = floodedq3 * had_mtg * post;
gen floodedq4_had_mtg_p = floodedq4 * had_mtg * post;


gen blkaatq = 0 if propaa ~= .;
replace blkaatq = 1 if propaa > 0.96 & propaa ~= .;

* interact block proportion tq African American with flood depth quartiles;
gen floodedq0_x_p_blkaatq = floodedq0_x_p * blkaatq;
gen floodedq1_x_p_blkaatq = floodedq1_x_p * blkaatq;
gen floodedq2_x_p_blkaatq = floodedq2_x_p * blkaatq;
gen floodedq3_x_p_blkaatq = floodedq3_x_p * blkaatq;
gen floodedq4_x_p_blkaatq = floodedq4_x_p * blkaatq;


gen post_blkaatq = post * blkaatq;
gen had_mtg_blkaatq_p = had_mtg * post_blkaatq;
gen floodedq0_had_mtg_blkaatq_p = floodedq0 * had_mtg * post_blkaatq;
gen floodedq1_had_mtg_blkaatq_p = floodedq1 * had_mtg * post_blkaatq;
gen floodedq2_had_mtg_blkaatq_p = floodedq2 * had_mtg * post_blkaatq;
gen floodedq3_had_mtg_blkaatq_p = floodedq3 * had_mtg * post_blkaatq;
gen floodedq4_had_mtg_blkaatq_p = floodedq4 * had_mtg * post_blkaatq;


gen riskscore_sq = riskscore^2;
gen riskscore_cu = riskscore^3;

* Calculate post interacted with elevation, flood risk, and demographic characteristics;
foreach v in 
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba {;
	gen `v'_p = `v' * post;
};
rename meanelev_cub meanelev_cu;
rename minelev_cub minelev_cu;
rename maxelev_cub maxelev_cu;

gen tract_str_2005q3_p = tract_str_2005q3 + string(post, "%01.0f");


save ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, replace;





* Calculate local-non-local share split;
use ../tmp_data/loans_1997_2002_by_nolacsa.dta;
append using ../tmp_data/loans_2003_2005_by_nolacsa.dta;

sum;

gen year = year(actdate);
tab year;

gen loans = 1;

collapse (sum) loans, by(HM5RID code nolacsa) fast;
drop if code == .;

reshape wide loans, i(HM5RID code) j(nolacsa);
gen shrnolacsa = loans1 / (loans0+loans1);
replace shrnolacsa = 1 if loans1~=. & loans0==.;

sum shrnolacsa, d;

compress;
sort HM5RID code;
save ../tmp_data/shrnolacsa_by_lender.dta, replace;




* More Dynamic measure of local lending using year and tract of loan;

use ../tmp_data/loans_1997_2002_by_nolacsa.dta;
append using ../tmp_data/loans_2003_2005_by_nolacsa.dta;

sum;

gen year = year(actdate);
tab year;

gen mdate = ym(year(actdate), month(actdate));
format mdate %tm;
tab mdate;

sort mdate;
merge m:1 mdate using ../raw_data/cpi_allitems_urban_monthly_not_sa.dta;
drop if _merge == 2;
drop _merge;

* put loan amount in year 2005 dollars;
replace loanamt = loanamt * cpi / 195.3;

* generate variable to count the number of loans;
gen numloans=1;


* create variables to examine the share of loans that were securitized or sold;
gen shrsec = 0 if purtype~=.;
replace shrsec = 1 if (purtype >= 1 & purtype <= 5);

gen shrprivsec = 0 if purtype~=.;
replace shrprivsec = 1 if (purtype == 5);

gen shrsold = 0 if purtype~=.;
replace shrsold = 1 if (purtype >= 1 & purtype <= 9);



* find the total amount of loans and loan totals by institution and location;
* for the full pre-Katrina period;

collapse (sum) loanamt numloans (mean) shrsec shrprivsec shrsold, by (HM5RID code nolacsa year) fast;

reshape wide loanamt numloans shrsec shrprivsec shrsold, i(HM5RID code year) j(nolacsa);

gen shr_nolacsa_num_full = numloans1 / (numloans0 + numloans1);
gen shr_nolacsa_bal_full = loanamt1 / (loanamt0 + loanamt1);

gen total_num_full = (numloans0 + numloans1);
gen total_bal_full = (loanamt0 + loanamt1);

rename numloans1 nolacsa_num_full;
rename loanamt1 nolacsa_bal_full;

rename shrsold1 shrsold_full;
rename shrsec1 shrsec_full;

drop if year == .;

compress;
rename HM5RID hm5rid;
sort hm5rid code year;

keep hm5rid code year shr_nolacsa_num_full shr_nolacsa_bal_full total_num_full total_bal_full nolacsa_num_full nolacsa_bal_full shrsold_full shrsec_full;

save ../tmp_data/nolacsa_lending_shares_annual_1997_2005Q2.dta, replace;


* Distill raw HMDA files down to only necessary variables;

* create file that maps 1990 tract numbers to the 2000 New Orleans CSA;
insheet using ../raw_data/la_al_tract_msa_map_1990.csv, clear;

replace tract = round(censustractbna*100);
gen tract_str = string(county, "%05.0f") + string(tract, "%06.0f");

keep if msaorcmsa == 5560;
sort tract_str;
count if tract_str == tract_str[_n-1];
sum tracttomsacmsaallocfactor;
tab tracttomsacmsaallocfactor;
keep tract_str;

save ../tmp_data/new_orleans_cmsa_tracts_1990.dta, replace;
clear;



    


************************************************************;
* Make tract-level variables.  THis way we can convert the;
* pre 2003 data to year 2000 tract boundaries;
************************************************************;

* Start by converting pre 2003 HMDA data to 2000 tract boundaries;

use ../tmp_data/katrina_csa_tracts_hmda_microdata.dta;

* only keep loans that were made;
keep if action == 1;

* drop any HMDA data that occurs after Katrina hits;
drop if actdate > mdy(8,28,2005);

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta;
drop if _merge == 2;
drop _merge;

keep if year < 2003;

gen obs = 1;

collapse (sum) obs (mean) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full, by(tract_str year) fast;

sum branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full;

rename tract_str tract_id_1990;
sort tract_id_1990; 
joinby tract_id_1990 using ../raw_data/relationshipfile1990to2000.dta;

foreach v in branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full {;
  replace `v' = `v' * percent1990tract / 100;
};

collapse (sum) obs (sum) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full, by(tract_id_2000 year) fast;
rename tract_id_2000 tract_str;

sort tract_str;
merge m:1 tract_str using ../tmp_data/depthcoverage_tracts.dta;
keep if _merge == 3;
drop _merge;

sum branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full obs;

gen tract_boundary = 1990;

compress;
save ../tmp_data/katrina_pre2003_tractmeans_annual.dta, replace;



* Next take means of the 2003-Katina data;

use ../tmp_data/katrina_csa_tracts_hmda_microdata.dta;

* only keep loans that were made;
keep if action == 1;

drop if actdate > mdy(8,28,2005);

sort hm5rid code;
merge m:1  hm5rid code using ../tmp_data/nolacsa_lending_shares_1997_2005Q2.dta;
drop if _merge == 2;
drop _merge;

keep if year >= 2003;

gen obs = 1;

collapse (sum) obs (mean) branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_bal_full, by(tract_str year) fast;

sort tract_str;
merge m:1 tract_str using ../tmp_data/depthcoverage_tracts.dta;
keep if _merge == 3;
drop _merge;

gen tract_boundary = 2000;

compress;
save ../tmp_data/katrina_post2002_tractmeans_annual.dta, replace;

append using ../tmp_data/katrina_pre2003_tractmeans_annual.dta;

sort tract_str year;
count if tract_str == tract_str[_n-1] & year == year[_n-1];

compress;
save ../tmp_data/katrina_tractmeans_annual.dta, replace;






    
* prepare branch presence data;    
use ../tmp_data/katrina_csa_tracts_hmda_microdata.dta;
rename hm5rid HM5RID;

* only keep loans that were made;
keep if action == 1;
* only keep pre-Katrina data;
drop if actdate > mdy(8,28,2005);

collapse (max) max_branchin_nocsa_hudnb=branchin_nocsa_hudnb (min) min_branchin_nocsa_hudnb=branchin_nocsa_hudnb, by(HM5RID code) fast;

count;
count if max_branchin_nocsa_hudnb ~= min_branchin_nocsa_hudnb;

* call it local if it ever had a branch in NO CSA;
drop min_branchin_nocsa_hudnb;
rename max_branchin_nocsa_hudnb branchin_nocsa_hudnb;

compress;
sort HM5RID code;
save ../tmp_data/branch_in_nocsa_by_lender.dta, replace;
clear matrix;


    

* Residential real estate transactions;

use ../raw_data/nola_parcel_transactions.dta;

* keep only residential transactions;
keep if propertyclass == "Residential";

* keep only tranacstions with a census block that is knowm;
drop if stfid == "";

gen sdate = date(date, "MDY");
format sdate %td;
drop if sdate == .;

gen qdate = yq(year(sdate), quarter(sdate));
format qdate %tq;

gen year = year(sdate);

drop if year < 1995;

tab year;


destring price, replace ignore(",");

count if year >= 2002 & year <= 2008;
count if price==0 & year >= 2002 & year <= 2008;

gen dzero = (price == 0);

gen before = 0 if (qdate >= yq(2004,3) & qdate <= yq(2005,2));
replace before = 1 if (qdate >= yq(2005,4) & qdate <= yq(2006,3));

* checking to see if the share of 0's spikes after Katrina;
table qdate, c(mean dzero);
table year, c(mean dzero);
table before, c(mean dzero);

drop if price == 0;

gen trans = 1;


collapse (sum) trans (sum) price, by(stfid qdate) fast;

tab qdate;
rename stfid block_str;

sort qdate;
merge m:1 qdate using ../raw_data/cpi_allitems_urban_quarterly_not_sa.dta;
drop  if _merge == 2;
drop _merge;

* put in terms of 2005q2 dollars;
replace price = 194.5 * price / cpi;

sort block_str qdate;

compress;
save ../tmp_data/home_sales_by_block_quarter.dta, replace;




* Local vs. non-Local Analysis;

* Make tract-level flood depth quartile variables to use with HMDA data;

use ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta;
gen tract_str = substr(block_str, 1, 11);

collapse (mean) maxmeandepth propa meanelev qdepth, by(tract_str) fast;
sum;

gen qdepth2 = round(qdepth);

drop qdepth;
xtile qdepth = maxmeandepth if maxmeandepth~=0, nq(4);
replace qdepth = 0 if maxmeandepth == 0;
tab qdepth;

sort tract_str;
save ../tmp_data/rough_tract_floooddepth.dta, replace;




* Local vs. non-Local Analysis;

* want to merge this file in based on tract_str and year  mortgage was originated;    

use ../raw_data/mortgage_tl_depthcoverage_ever.dta, clear;

gen openyear = floor(opendate / 100);
gsort cid tlid qtr -balance;
count if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1];
tab continue_flag_d if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1] & balance == 0, m;
drop if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1] & balance == 0;
gsort cid tlid qtr -balance;

keep if year(qtr) == 2005 & quarter(qtr) == 3;
gsort cid -balance;
drop if cid == cid[_n-1];

keep cid openyear;
compress;
sort cid;
save ../tmp_data/largest_mtg_bal_open_year.dta, replace;
clear;



* robustness using only people who have 1 mortgage;    

use ../raw_data/mortgage_tl_depthcoverage_ever.dta;

gen openyear = floor(opendate / 100);
gsort cid tlid qtr -balance;
count if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1];
tab continue_flag_d if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1] & balance == 0, m;
drop if cid==cid[_n-1] & tlid==tlid[_n-1] & qtr==qtr[_n-1] & balance == 0;
gsort cid tlid qtr -balance;

keep if year(qtr) == 2005 & quarter(qtr) == 3;

gen obs = 1;
collapse (sum) obs (sum) openyear, by(cid) fast;

count;
count if obs > 1;
drop if obs > 1;

keep cid openyear;
compress;
sort cid;
save ../tmp_data_final2/single_mtg__open_year.dta, replace;
clear;


* zipcode to block mapping files for Justin;

insheet using ../raw_data/block2000_zcta2000_mapping_la_landarea.csv;
replace tract = round( tract * 100 );
gen block_str = string(county, "%05.0f") + string(tract, "%06.0f") + string(block, "%04.0f");

sum afact;

keep block_str zcta5;
sort block_str;

saveold ../tmp_data_final2/block_zip_map_2000_landarea.dta, replace;


use ../tmp_data_final2/depthcoverage_blocks.dta;
sort block_str;
merge 1:1 block_str using ../tmp_data_final2/block_zip_map_2000_landarea.dta;
drop if _merge == 2;
tab _merge;
drop _merge;

saveold ../tmp_data_final2/depthcoverage_blocks_zcta5.dta, replace;








// Create list of CIDs in our core sample (present during Katrina and full 0208 panel);
use ../tmp_data_final2/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta;

tab qdate qdepth if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (age ~=. & lmedoohval ~= . );

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate==yq(2005, 2) & age ~=. & lmedoohval ~= . );

keep cid;
sort cid;
drop if cid==cid[_n-1];
                                                                                          
count;
outsheet using ../tmp_data_final2/cid_list_in_fullsample0208_qdepth014.csv, comma replace noquote;



use ../tmp_data_final2/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

tsset ncid qdate;

tab qdate qdepth if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (age ~=. & lmedoohval ~= . );

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate==yq(2005, 2) & age ~=. & lmedoohval ~= . ) & f3.gt1_home_tot_imp==0 & had_mtg==1;

tab qdate qdepth if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (age ~=. & lmedoohval ~= . );

keep cid qdepth had_mtg;
sort cid;
count if cid==cid[_n-1];

save ../tmp_data_final2/q014_cid_qdepth_mtg.dta, replace;



use ../raw_data/frbnyccp_100pct_primary_cid_mtg_vars_3counties.dta, clear;

gen qdate = qofd(qtr);
format qdate %tq;

* Merge in state fips codes;

sort state;
merge m:1 state using ../raw_data/state_fips.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

* Current block of residence;
gen block_str = string(state_code, "%02.0f") + county_code + census_tract + census_block;


rename crtr_attr1 num_all_tot;
rename crtr_attr6 num_fmrtg_tot;
rename crtr_attr7 num_helin_tot;
rename crtr_attr8 num_helre_tot;
gen num_home_tot = num_fmrtg_tot + num_helin_tot + num_helre_tot;

gen gt1_home_tot = 0 if num_home_tot ~= .;
replace gt1_home_tot = 1 if num_home_tot > 0 & num_home_tot ~= .;

gen obs = 1;

collapse (sum) gt1_home_tot obs, by(block_str qdate) fast;

* (mean) f65p fhisp medoohval faa fforborn povrate fba foo lmedhhinc lmedoohval maxmeandepth propa propx500 meanelev maxelev minelev qdepth;

* Merge in flood depth data based on block;
sort block_str;
merge m:1 block_str using ../tmp_data_final2/nola_w_algiers_flood_risk_katrina_depth.dta;
tab _merge;
drop if _merge == 1;

table qdate if qdepth==4 & _merge==3, c(sum gt1_home_tot sum obs);


replace qdate = yq(1999, 1) if _merge == 2;
egen nblock_str = group(block_str);
tsset nblock_str qdate, quarterly;
tsfill, full;

sum gt1_home_tot;
replace gt1_home_tot = 0 if gt1_home_tot == .;
sum gt1_home_tot;

sum obs;
replace obs = 0 if obs == .;
sum obs;

gsort nblock_str -qdate;
replace qdepth = qdepth[_n-1] if qdepth == . & qdepth[_n-1] ~= . & nblock_str==nblock_str[_n-1];
gsort nblock_str qdate;
replace qdepth = qdepth[_n-1] if qdepth == . & qdepth[_n-1] ~= . & nblock_str==nblock_str[_n-1];

gsort nblock_str -qdate;
replace block_str = block_str[_n-1] if block_str == "" & block_str[_n-1] ~= "" & nblock_str==nblock_str[_n-1];
gsort nblock_str qdate;
replace block_str = block_str[_n-1] if block_str == "" & block_str[_n-1] ~= "" & nblock_str==nblock_str[_n-1];

tab qdate qdepth;

keep qdate qdepth nblock_str gt1_home_tot block_str obs;
count if block_str =="";

sort block_str;
merge m:1 block_str using ../tmp_data_final2/nola_w_algiers_flood_risk_katrina_depth.dta;



gen post = ( qdate > yq(2005, 3) );

gen flooded = ( maxmeandepth > 0 );
gen flooded_x_p = flooded * post;

gen floodedq0 = (qdepth == 0);
gen floodedq1 = (qdepth == 1);
gen floodedq2 = (qdepth == 2);
gen floodedq3 = (qdepth == 3);
gen floodedq4 = (qdepth == 4);

gen floodedq0_x_p = floodedq0 * post;
gen floodedq1_x_p = floodedq1 * post;
gen floodedq2_x_p = floodedq2 * post;
gen floodedq3_x_p = floodedq3 * post;
gen floodedq4_x_p = floodedq4 * post;


gen meanelev_sq  = meanelev^2;
gen maxelev_sq = maxelev^2;
gen minelev_sq = minelev^2;

gen meanelev_cub = meanelev^3;
gen maxelev_cub = maxelev^3;
gen minelev_cub = minelev^3;

gen propa_sq = propa^2;
gen propa_cu = propa^3;

gen propa_x_elev = propa * meanelev;


gen maxmeandepth_x_2006q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2006q3 = maxmeandepth if qdate == yq(2006, 3);

gen maxmeandepth_x_2007q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2007q3 = maxmeandepth if qdate == yq(2007, 3);

gen maxmeandepth_x_2008q3 = 0 if maxmeandepth ~= .;
replace maxmeandepth_x_2008q3 = maxmeandepth if qdate == yq(2008, 3);

gen dpropa = (propa > 0.99);



	gen d2001q1 = (qdate == yq(2001, 1));
	gen d2001q2 = (qdate == yq(2001, 2));
	gen d2001q3 = (qdate == yq(2001, 3));
	gen d2001q4 = (qdate == yq(2001, 4));
	gen d2002q1 = (qdate == yq(2002, 1));
	gen d2002q2 = (qdate == yq(2002, 2));
	gen d2002q3 = (qdate == yq(2002, 3));
	gen d2002q4 = (qdate == yq(2002, 4));
	gen d2003q1 = (qdate == yq(2003, 1));
	gen d2003q2 = (qdate == yq(2003, 2));
	gen d2003q3 = (qdate == yq(2003, 3));
	gen d2003q4 = (qdate == yq(2003, 4));
	gen d2004q1 = (qdate == yq(2004, 1));
	gen d2004q2 = (qdate == yq(2004, 2));
	gen d2004q3 = (qdate == yq(2004, 3));
	gen d2004q4 = (qdate == yq(2004, 4));
	gen d2005q1 = (qdate == yq(2005, 1));
	gen d2005q2 = (qdate == yq(2005, 2));
	gen d2005q3 = (qdate == yq(2005, 3));
	gen d2005q4 = (qdate == yq(2005, 4));
	gen d2006q1 = (qdate == yq(2006, 1));
	gen d2006q2 = (qdate == yq(2006, 2));
	gen d2006q3 = (qdate == yq(2006, 3));
	gen d2006q4 = (qdate == yq(2006, 4));
	gen d2007q1 = (qdate == yq(2007, 1));
	gen d2007q2 = (qdate == yq(2007, 2));
	gen d2007q3 = (qdate == yq(2007, 3));
	gen d2007q4 = (qdate == yq(2007, 4));
	gen d2008q1 = (qdate == yq(2008, 1));
	gen d2008q2 = (qdate == yq(2008, 2));
	gen d2008q3 = (qdate == yq(2008, 3));
	gen d2008q4 = (qdate == yq(2008, 4));
	gen d2009q1 = (qdate == yq(2009, 1));
	gen d2009q2 = (qdate == yq(2009, 2));
	gen d2009q3 = (qdate == yq(2009, 3));
	gen d2009q4 = (qdate == yq(2009, 4));
	gen d2010q1 = (qdate == yq(2010, 1));
	gen d2010q2 = (qdate == yq(2010, 2));
	gen d2010q3 = (qdate == yq(2010, 3));
	gen d2010q4 = (qdate == yq(2010, 4));
	gen d2011q1 = (qdate == yq(2011, 1));
	gen d2011q2 = (qdate == yq(2011, 2));
	gen d2011q3 = (qdate == yq(2011, 3));
	gen d2011q4 = (qdate == yq(2011, 4));
	gen d2012q1 = (qdate == yq(2012, 1));
	gen d2012q2 = (qdate == yq(2012, 2));
	gen d2012q3 = (qdate == yq(2012, 3));
	gen d2012q4 = (qdate == yq(2012, 4));
	gen d2013q1 = (qdate == yq(2013, 1));
	gen d2013q2 = (qdate == yq(2013, 2));
	gen d2013q3 = (qdate == yq(2013, 3));
	gen d2013q4 = (qdate == yq(2013, 4));
	gen d2014q1 = (qdate == yq(2014, 1));
	gen d2014q2 = (qdate == yq(2014, 2));
	gen d2014q3 = (qdate == yq(2014, 3));
	gen d2014q4 = (qdate == yq(2014, 4));
	gen d2015q1 = (qdate == yq(2015, 1));
	gen d2015q2 = (qdate == yq(2015, 2));
	gen d2015q3 = (qdate == yq(2015, 3));


	* 0. Define these new variables;

	* Quartile Depth postflood variables;
	forvalues q = 0/4 {;
	gen floodedq`q'_x_2001q1 = floodedq`q'*d2001q1;
	gen floodedq`q'_x_2001q2 = floodedq`q'*d2001q2;
	gen floodedq`q'_x_2001q3 = floodedq`q'*d2001q3;
	gen floodedq`q'_x_2001q4 = floodedq`q'*d2001q4;
	gen floodedq`q'_x_2002q1 = floodedq`q'*d2002q1;
	gen floodedq`q'_x_2002q2 = floodedq`q'*d2002q2;
	gen floodedq`q'_x_2002q3 = floodedq`q'*d2002q3;
	gen floodedq`q'_x_2002q4 = floodedq`q'*d2002q4;
	gen floodedq`q'_x_2003q1 = floodedq`q'*d2003q1;
	gen floodedq`q'_x_2003q2 = floodedq`q'*d2003q2;
	gen floodedq`q'_x_2003q3 = floodedq`q'*d2003q3;
	gen floodedq`q'_x_2003q4 = floodedq`q'*d2003q4;
	gen floodedq`q'_x_2004q1 = floodedq`q'*d2004q1;
	gen floodedq`q'_x_2004q2 = floodedq`q'*d2004q2;
	gen floodedq`q'_x_2004q3 = floodedq`q'*d2004q3;
	gen floodedq`q'_x_2004q4 = floodedq`q'*d2004q4;
	gen floodedq`q'_x_2005q1 = floodedq`q'*d2005q1;
	gen floodedq`q'_x_2005q2 = floodedq`q'*d2005q2;
	gen floodedq`q'_x_2005q3 = floodedq`q'*d2005q3;
	gen floodedq`q'_x_2005q4 = floodedq`q'*d2005q4;
	gen floodedq`q'_x_2006q1 = floodedq`q'*d2006q1;
	gen floodedq`q'_x_2006q2 = floodedq`q'*d2006q2;
	gen floodedq`q'_x_2006q3 = floodedq`q'*d2006q3;
	gen floodedq`q'_x_2006q4 = floodedq`q'*d2006q4;
	gen floodedq`q'_x_2007q1 = floodedq`q'*d2007q1;
	gen floodedq`q'_x_2007q2 = floodedq`q'*d2007q2;
	gen floodedq`q'_x_2007q3 = floodedq`q'*d2007q3;
	gen floodedq`q'_x_2007q4 = floodedq`q'*d2007q4;
	gen floodedq`q'_x_2008q1 = floodedq`q'*d2008q1;
	gen floodedq`q'_x_2008q2 = floodedq`q'*d2008q2;
	gen floodedq`q'_x_2008q3 = floodedq`q'*d2008q3;
	gen floodedq`q'_x_2008q4 = floodedq`q'*d2008q4;
	gen floodedq`q'_x_2009q1 = floodedq`q'*d2009q1;
	gen floodedq`q'_x_2009q2 = floodedq`q'*d2009q2;
	gen floodedq`q'_x_2009q3 = floodedq`q'*d2009q3;
	gen floodedq`q'_x_2009q4 = floodedq`q'*d2009q4;
	gen floodedq`q'_x_2010q1 = floodedq`q'*d2010q1;
	gen floodedq`q'_x_2010q2 = floodedq`q'*d2010q2;
	gen floodedq`q'_x_2010q3 = floodedq`q'*d2010q3;
	gen floodedq`q'_x_2010q4 = floodedq`q'*d2010q4;
	gen floodedq`q'_x_2011q1 = floodedq`q'*d2011q1;
	gen floodedq`q'_x_2011q2 = floodedq`q'*d2011q2;
	gen floodedq`q'_x_2011q3 = floodedq`q'*d2011q3;
	gen floodedq`q'_x_2011q4 = floodedq`q'*d2011q4;
	gen floodedq`q'_x_2012q1 = floodedq`q'*d2012q1;
	gen floodedq`q'_x_2012q2 = floodedq`q'*d2012q2;
	gen floodedq`q'_x_2012q3 = floodedq`q'*d2012q3;
	gen floodedq`q'_x_2012q4 = floodedq`q'*d2012q4;
	gen floodedq`q'_x_2013q1 = floodedq`q'*d2013q1;
	gen floodedq`q'_x_2013q2 = floodedq`q'*d2013q2;
	gen floodedq`q'_x_2013q3 = floodedq`q'*d2013q3;
	gen floodedq`q'_x_2013q4 = floodedq`q'*d2013q4;
	gen floodedq`q'_x_2014q1 = floodedq`q'*d2014q1;
	gen floodedq`q'_x_2014q2 = floodedq`q'*d2014q2;
	gen floodedq`q'_x_2014q3 = floodedq`q'*d2014q3;
	gen floodedq`q'_x_2014q4 = floodedq`q'*d2014q4;
	gen floodedq`q'_x_2015q1 = floodedq`q'*d2015q1;
	gen floodedq`q'_x_2015q2 = floodedq`q'*d2015q2;
	gen floodedq`q'_x_2015q3 = floodedq`q'*d2015q3;
	};

	gen d2001 = (year(dofq(qdate)) == 2001);
	gen d2002 = (year(dofq(qdate)) == 2002);
	gen d2003 = (year(dofq(qdate)) == 2003);
	gen d2004 = (year(dofq(qdate)) == 2004);
	gen d2005 = (year(dofq(qdate)) == 2005);
	gen d2006 = (year(dofq(qdate)) == 2006);
	gen d2007 = (year(dofq(qdate)) == 2007);
	gen d2008 = (year(dofq(qdate)) == 2008);
	gen d2009 = (year(dofq(qdate)) == 2009);

	forvalues y = 2001/2009 {;
  	  forvalues q = 0/4 {;
	    gen floodedq`q'_x_`y' = floodedq`q'*d`y';
	  };
	};

	gen depth_x_post = maxmeandepth * post;
	forvalues y = 2001/2009 {;
	    gen depth_x_`y' = maxmeandepth*d`y';
	};
	


* Calculate post interacted with elevation, flood risk, and demographic characteristics;
foreach v in 
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba {;
	gen `v'_p = `v' * post;
};
rename meanelev_cub meanelev_cu;
rename minelev_cub minelev_cu;
rename maxelev_cub maxelev_cu;

save ../tmp_data_final2/block_level_ccp_pop_num_home_loan.dta, replace;



* Setting up local-ness of mortgage variables;

use ../tmp_data_final2/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & propaa ~=. & riskscore ~=.;

sum gt1_home_tot_imp if qdate==yq(2005,2) & (pres_during_katrina == 1 ) & (qdepth == 0) & fullsample0208==1 & propaa ~=. & riskscore ~=.;
sum gt1_home_tot_imp if qdate==yq(2006,1) & (pres_during_katrina == 1 ) & (qdepth == 0) & fullsample0208==1 & propaa ~=. & riskscore ~=.;
sum gt1_home_tot_imp if qdate==yq(2006,2) & (pres_during_katrina == 1 ) & (qdepth == 0) & fullsample0208==1 & propaa ~=. & riskscore ~=.;


sum gt1_home_tot_imp if qdate==yq(2005,2) & (pres_during_katrina == 1 ) & (qdepth == 4) & fullsample0208==1 & propaa ~=. & riskscore ~=.;
sum gt1_home_tot_imp if qdate==yq(2006,1) & (pres_during_katrina == 1 ) & (qdepth == 4) & fullsample0208==1 & propaa ~=. & riskscore ~=.;
sum gt1_home_tot_imp if qdate==yq(2006,2) & (pres_during_katrina == 1 ) & (qdepth == 4) & fullsample0208==1 & propaa ~=. & riskscore ~=.;



drop branchin_nocsa_hudnb shr_nolacsa_num_full shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre;
rename tract_str_2005q3 tract_str;
sort tract_str;


* mapping between mortgage borrowers and the year they opened largest loan;
sort cid;
merge m:1 cid using ../tmp_data_final2/single_mtg__open_year.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

tab openyear if had_mtg == 1 & qdate==yq(2005,3), m;

drop year;
rename openyear year;
sort tract_str year;
merge m:1 tract_str year using ../tmp_data_final2/katrina_tractmeans_annual.dta;
drop if _merge == 2;
drop _merge;

gen shr_nolacsa_num_full_1mtg_nm = shr_nolacsa_num_full;

drop obs branchin_nocsa_hudnb shr_nolacsa_bal_full tract_boundary year;

* for borrowers with a year prior to 1997 use tract average;
sort tract_str;
merge m:1 tract_str using ../tmp_data/katrina_tractmeans.dta, update;
drop if _merge == 2;
drop _merge;

rename shr_nolacsa_num_full shr_nolacsa_num_full_1mtg;
* Only keep _1mtg and _1mtg_nm;
drop branchin_nocsa_hudnb shr_nolacsa_num_pre shr_nolacsa_bal_full shr_nolacsa_bal_pre;


* mapping between mortgage borrowers and the year they opened largest loan;
sort cid;
merge m:1 cid using ../tmp_data_final2/largest_mtg_bal_open_year.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

tab openyear if had_mtg == 1 & qdate==yq(2005,3), m;

rename openyear year;
sort tract_str year;
merge m:1 tract_str year using ../tmp_data_final2/katrina_tractmeans_annual.dta;
drop if _merge == 2;
drop _merge;

drop obs;

gen shr_nolacsa_num_full_nomeans = shr_nolacsa_num_full;

rename year openyear;
gen year = year(dofq(qdate));

* for borrowers with a year prior to 1997 use tract average;
sort tract_str year;
merge m:1 tract_str using ../tmp_data/katrina_tractmeans.dta, update;
drop if _merge == 2;
drop _merge;

rename tract_str tract_str_2005q3;

sum shr_nolacsa_num_full_1mtg if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4);
sum shr_nolacsa_num_full_nomeans if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4);
sum shr_nolacsa_num_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4);



* Need to determine Local non-Local threshold.  split estimation sample in half;

sum branchin_nocsa_hudnb if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1  & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh1 = `r(p50)';
disp(`nlthresh1');

sum shr_nolacsa_num_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh2 = `r(p50)';
disp(`nlthresh2');

sum shr_nolacsa_num_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh3 = `r(p50)';
disp(`nlthresh3');

sum shr_nolacsa_bal_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1  & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh4 = `r(p50)';
disp(`nlthresh4');

sum shr_nolacsa_bal_full if qdate==yq(2005,3) & pres_during_katrina==1 & fullsample0208==1 & had_mtg==1 & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4), d;
local nlthresh5 = `r(p50)';
disp(`nlthresh5');



gen nl1 = 0 if branchin_nocsa_hudnb ~=.;
replace nl1 = 1 if branchin_nocsa_hudnb <= `nlthresh1';

gen nl2 = 0 if shr_nolacsa_num_full ~=.;
replace nl2 = 1 if shr_nolacsa_num_full <= `nlthresh2';

gen nl3 = 0 if shr_nolacsa_num_full ~=.;
replace nl3 = 1 if shr_nolacsa_num_full <= `nlthresh3';

gen nl4 = 0 if shr_nolacsa_bal_full ~=.;
replace nl4 = 1 if shr_nolacsa_bal_full <= `nlthresh4';

gen nl5 = 0 if shr_nolacsa_bal_full ~=.;
replace nl5 = 1 if shr_nolacsa_bal_full <= `nlthresh5';


gen nl6 = shr_nolacsa_num_full_1mtg_nm;
gen nl7 = shr_nolacsa_num_full_1mtg;

gen nl8 = shr_nolacsa_num_full_nomeans;
gen nl9 = shr_nolacsa_num_full;
gen nl10 = shr_nolacsa_num_full;

gen nl11 = shr_nolacsa_bal_full;
gen nl12 = branchin_nocsa_hudnb;

forvalues i=1/12 {;
  gen post_nl`i' = post * nl`i';

  forvalues q=1/4 {;
    gen floodedq`q'_nl`i' = floodedq`q' * nl`i';
    gen floodedq`q'_x_p_nl`i' = floodedq`q'_x_p * nl`i';
  };
};


gen shr_bal_claim_p = shr_bal_claim * post;

bys cid: egen tmp_rsmean_pre = mean(riskscore) if qdate <= yq(2005,2);
bys cid: egen rsmean_pre = min(tmp_rsmean_pre);
drop tmp_rsmean_pre;
gen rsmean_pre_sq = rsmean_pre^2;
gen rsmean_pre_cu = rsmean_pre^3;

gen rsmean_pre_p = rsmean_pre * post;
gen rsmean_pre_sq_p = rsmean_pre_sq * post;
gen rsmean_pre_cu_p = rsmean_pre_cu * post;

gen placenm = "";

save ../tmp_data_final2/tmp_local_nonlocal.dta, replace;


* Make file with total home sales in two quarters following Katrina;

use ../tmp_data_final2/home_sales_by_block_quarter.dta;
keep if qdate==yq(2005,4) | qdate==yq(2006,1);
collapse (sum) trans price, by(block_str) fast;
sort block_str;
save ../tmp_data_final2/home_sales_by_block_2qafter_katrina.dta, replace;


log close;

