# delimit;
set more off;

log using ../logs/katrina_appendix.txt, text replace;


* Appendix Table 1;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow.dta;

keep if qdate == yq(2000, 2);

keep if depthcoverage_block == 1;

count;
sum birthyear;
gen age = 2000 - birthyear if birthyear ~= 0;
sum age;

* drop the deceased;
drop if cust_attr292 == "Y";


keep block_str age;

gen eqfobs = 1;

gen age_bin = 0 if age == .;
replace age_bin = 1 if age < 18;
replace age_bin = 2 if age >= 18 & age <= 24;
replace age_bin = 3 if age >= 25 & age <= 34;
replace age_bin = 4 if age >= 35 & age <= 44;
replace age_bin = 5 if age >= 45 & age <= 54;
replace age_bin = 6 if age >= 55 & age <= 64;
replace age_bin = 7 if age >= 65 & age <= 74;
replace age_bin = 8 if age >= 75 & age ~= .;

collapse (sum) eqfobs, by(block_str age_bin);
reshape wide eqfobs, i(block_str) j(age_bin);

sort block_str;
merge m:1 block_str using ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta;
tab _merge;
drop _merge;

keep block_str eqfobs* qdepth;


sort block_str;
merge 1:1 block_str using ../raw_data/la_census2000_block_age.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

gen cenage1 = fym001 + fym002 + fym003 + fym004 + fym024 + fym025 + fym026 + fym027;
gen cenage2 = fym005 + fym006 + fym007 + fym008 + fym028 + fym029 + fym030 + fym031;
gen cenage3 = fym009 + fym010 + fym032 + fym033;
gen cenage4 = fym011 + fym012 + fym034 + fym035;
gen cenage5 = fym013 + fym014 + fym036 + fym037;
gen cenage6 = fym015 + fym016 + fym017 + fym038 + fym039 + fym040;
gen cenage7 = fym018 + fym019 + fym020 + fym041 + fym042 + fym043;
gen cenage8 = fym021 + fym022 + fym023 + fym044 + fym045 + fym046;

keep block_str eqfobs* cenage* qdepth;

forvalues i=0/8 {; 
  replace eqfobs`i' = 0 if eqfobs`i' == .;
  replace eqfobs`i' = 20 * eqfobs`i';
};

gen cenpop = cenage1 + cenage2 + cenage3 + cenage4 + cenage5 + cenage6 + cenage7 + cenage8;
gen eqfpop = eqfobs0 + eqfobs1 + eqfobs2 + eqfobs3 + eqfobs4 + eqfobs5 + eqfobs6 + eqfobs7 + eqfobs8;

gen coverage = eqfpop / cenpop;
gen missingage = eqfobs0 / cenpop;
forvalues i=1/8 {; 
  gen coverage`i' = eqfobs`i' / cenage`i';
};


table qdepth, c(sum cenpop sum eqfpop);


gen eqf18p = (eqfobs2 + eqfobs3 + eqfobs4 + eqfobs5 + eqfobs6 + eqfobs7 + eqfobs8);
gen cen18p = (cenage2 + cenage3 + cenage4 + cenage5 + cenage6 + cenage7 + cenage8);

gen eqf18to74 = (eqfobs2 + eqfobs3 + eqfobs4 + eqfobs5 + eqfobs6 + eqfobs7);
gen cen18to74 = (cenage2 + cenage3 + cenage4 + cenage5 + cenage6 + cenage7);

gen eqf18pma = (eqfobs0 + eqfobs2 + eqfobs3 + eqfobs4 + eqfobs5 + eqfobs6 + eqfobs7 + eqfobs8);
gen eqfma = eqfobs0;

collapse (sum) cenpop eqfpop eqf18p cen18p eqf18to74 cen18to74 eqf18pma eqfma, by(qdepth);

gen coverage = eqfpop / cenpop;
gen shrma = eqfma / eqfpop;
gen coverage18p = eqf18p / cen18p;
gen coverage18to74 = eqf18to74 / cen18to74;
gen coverage18pma = eqf18pma / cen18p;

// Appendix Table 1;

list qdepth cenpop eqfpop coverage shrma coverage18p coverage18to74 coverage18pma;

clear;


* Create Appendix Table 2;


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


* Appendix Table 2;
* Column 1: Repeat of Table 3 Column 7 specification;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~=.;

* Appendix Table 2;
* Column 2: Repeat of Table 3 Column 7 specification;
* but with old balances sample (assumes 0 balances;
* even if number of accounts is missing);

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];


use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if pres_during_katrina == 1 & qdepth~=. & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


* Appendix Table 2;
* Column 3: using only flood depth quartiles 1 and 4;

* pre/post flood depth quartiles;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];


* Column 4: using all flood depth quartiles and linear depth interaction;

* pre/post flood depth linear;
* adding a priori flood risk controls; 
* controlling for age;
* adding block group demgraphic characteristics;
* adding individual FE;
areg bal_all_tot_imp
	depth_x_post
	flooded_x_p
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = 0;
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ 0 ];
matrix results_new = [ results_new\ _b[depth_x_post] ];
matrix results_new = [ results_new\ _se[depth_x_post] ];
matrix results_new = [ results_new\ _b[flooded_x_p] ];
matrix results_new = [ results_new\ _se[flooded_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results_specs = [nullmat(results_specs), results_new];

* Appendix Table 2;
matrix list results_specs;
clear matrix;
clear;



* Create Appendix Table 3;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .;

clear matrix;

areg inq3m
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

areg numnewacct
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

areg numnewacct
	inq3m l1inq3m l2inq3m l3inq3m 
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

    

keep if num_all_tot ~= .;

areg bal_bcret_tot
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p

	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & belowmedrs == 0
	, robust cluster(block_str_2005q3) absorb(cid);


matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

areg bal_bcret_tot
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & belowmedrs == 1
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

areg bal_bcret_tot
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & avail_bcret_tot >= 500 & avail_bcret_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];


areg bal_bcret_tot
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post
	age age_sq age_cu 
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & avail_bcret_tot < 500 & avail_bcret_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];
matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];
matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix accttypes = [nullmat(accttypes), results_new];

* Appendix Table 3;
matrix list accttypes;

clear matrix;
 
clear;


* Appendix Table 4 - by neighborhood Justin created;

* Create Appendix Table 5;

* Damage rebuilding and migration regs;
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

sort block_str;
merge m:1 block_str using ../tmp_data/parcel_level_means_by_block.dta;
drop if _merge == 2;
drop _merge;

* how do damage measures correlate with flood depth?;
bys block_str: gen obsnum = _n; 
corr maxmeandepth parc_ddamage if obsnum == 1;
corr maxmeandepth parc_ddamage2 if obsnum == 1;

reg parc_ddamage maxmeandepth if obsnum == 1, robust;
reg parc_ddamage2 maxmeandepth if obsnum == 1, robust;


gen lbal_home_tot_imp = log(bal_home_tot_imp);


* Appendix Table 5 Column 3;
reg sameblock3yr claim_to_val lbal_home_tot_imp maxmeandepth pif04_byunit riskscore gt1_all_90 age age_sq age_cu if pres_during_katrina == 1 & fullsample0208==1 & qdate==yq(2005,3) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & had_mtg == 1, robust cluster(block_str_2005q3);

* Appendix Table 5 Column 4;
reg sameblock3yr claim_to_val lbal_home_tot_imp maxmeandepth pif04_byunit riskscore gt1_all_90 povrate foo lmedhhinc f65p faa fhisp fba age age_sq age_cu if pres_during_katrina == 1 & fullsample0208==1 & qdate==yq(2005,3) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & had_mtg == 1, robust cluster(block_str_2005q3);


sum claim_to_val if pres_during_katrina == 1 & fullsample0208==1 & qdate==yq(2005,3) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & had_mtg == 1, d;



* Do block-level regressions;

* Prepare block-level means;
keep if qdate==yq(2005,3);
collapse (mean) parc_ddamage parc_ddamage2 parc_drebuilt parc_drebuilt2 parc_drebuiltcdamage parc_drebuiltcdamage2 claim_to_val bal_home_tot_imp maxmeandepth pif04_byunit riskscore gt1_all_90 povrate foo lmedhhinc f65p faa fhisp fba age lmedoohval, by(block_str);
drop parc_*;
sort block_str;
save ../tmp_data/block_level_vars_for_parcel_level_regs.dta, replace;


* Appendix Table 6;

* Parcel level regressions;

use ../tmp_data/parcel_level_data.dta, clear;
sort block_str;
merge m:1 block_str using ../tmp_data/block_level_vars_for_parcel_level_regs.dta;
drop if _merge == 2;
drop _merge;

gen dbal_home_tot_imp_zero = (bal_home_tot_imp == 0);
gen lbal_home_tot_imp = log(bal_home_tot_imp);
replace lbal_home_tot_imp = 0 if dbal_home_tot_imp_zero == 1;

* Appendix Table 6 Column 3;
reg drebuiltcdamage2  claim_to_val lbal_home_tot_imp dbal_home_tot_imp_zero maxmeandepth pif04_byunit if ddamage2==1 & lmedhhinc ~= . & riskscore ~= . & gt1_all_90 ~= . & age ~= ., robust cluster(block_str);

* Appendix Table 6 Column 4;
reg drebuiltcdamage2  claim_to_val lbal_home_tot_imp dbal_home_tot_imp_zero maxmeandepth pif04_byunit riskscore gt1_all_90 povrate foo lmedhhinc f65p faa fhisp fba age if ddamage2==1 & lmedhhinc ~= . & riskscore ~= . & gt1_all_90 ~= . & age ~= ., robust cluster(block_str);

    

* Appendix Table 7;

* For local non-local robustness table;
clear matrix;

use ../tmp_data/tmp_local_nonlocal.dta, clear;

* Appendix Table 7;
* Column 1;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];


* Appendix Table 7;
* Column 2;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl11 floodedq2_x_p_nl11 floodedq3_x_p_nl11 floodedq4_x_p_nl11
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl11
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl11 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl11] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl11] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl11] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl11] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl11] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl11] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl11] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl11] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];



* Appendix Table 7;
* Column 3;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl12 floodedq2_x_p_nl12 floodedq3_x_p_nl12 floodedq4_x_p_nl12
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl12
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl12 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl12] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl12] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl12] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl12] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl12] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl12] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl12] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl12] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];


* Appendix Table 7;
* Column 4;
* drop people with pre 1997 mortgages;

areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=. & openyear >= 1997
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];




* Appendix Table 7;
* Column 5;
areg gt1_home_tot_imp_had_mtg
	floodedq1_x_p_nl10 floodedq2_x_p_nl10 floodedq3_x_p_nl10 floodedq4_x_p_nl10
	floodedq1_x_p_blkaatq floodedq2_x_p_blkaatq floodedq3_x_p_blkaatq floodedq4_x_p_blkaatq
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
	post_blkaatq
	post_nl10
	post
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	age age_sq age_cu
	rsmean_pre_p rsmean_pre_sq_p rsmean_pre_cu_p
	shr_bal_claim_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))  & nl10 ~=. & propaa ~=. & riskscore ~=.
	, robust cluster(tract_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq1_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p_nl10] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p_nl10] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p_nl10] ];

matrix results_new = [ results_new\ e(r2) ];
matrix results_new = [ results_new\ e(N) ];
matrix results = [nullmat(results), results_new];

* Appendix Table 7;
matrix list results;
clear matrix;




* Create Appendix Table 8;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


gen t1 = 0 if qdepth == 0;
replace t1 = 1 if qdepth == 1;
gen t2 = 0 if qdepth == 0;
replace t2 = 1 if qdepth == 2;
gen t3 = 0 if qdepth == 0;
replace t3 = 1 if qdepth == 3;
gen t4 = 0 if qdepth == 0;
replace t4 = 1 if qdepth == 4;

sort cid qdate;

* FLooded Quartile 1 estimating pscore;
dprobit t1 age age_sq age_cu 
        meanelev minelev maxelev
        meanelev_sq minelev_sq maxelev_sq
        meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        if qdate==yq(2005,2);

predict tmp_pwt1 if qdate==yq(2005,2) & (qdepth == 0 | qdepth == 1), pr;

* Min/Max trim;
* trim above control max;
sum tmp_pwt1 if qdepth == 0;
gen tmp_pwt1tr1 = tmp_pwt1 if tmp_pwt1 <= `r(max)';
* trim below treated min;
sum tmp_pwt1 if qdepth == 1;
replace tmp_pwt1tr1 = . if tmp_pwt1 <= `r(min)';

* 10/90 trim;
gen tmp_pwt1tr2 = tmp_pwt1 if ( tmp_pwt1 >= 0.1 & tmp_pwt1 <= 0.9 );

sum tmp_pwt1tr1;
sum tmp_pwt1tr2;
by cid: egen pwt1tr1 = min(tmp_pwt1tr1); 
by cid: egen pwt1tr2 = min(tmp_pwt1tr2); 


* FLooded Quartile 2 estimating pscore;
dprobit t2 age age_sq age_cu 
        meanelev minelev maxelev
        meanelev_sq minelev_sq maxelev_sq
        meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        if qdate==yq(2005,2);

predict tmp_pwt2 if qdate==yq(2005,2) & (qdepth == 0 | qdepth == 2), pr;

* Min/Max trim;
* trim above control max;
sum tmp_pwt2 if qdepth == 0;
gen tmp_pwt2tr1 = tmp_pwt2 if tmp_pwt2 <= `r(max)';
* trim below treated min;
sum tmp_pwt2 if qdepth == 2;
replace tmp_pwt2tr1 = . if tmp_pwt2 <= `r(min)';

* 10/90 trim;
gen tmp_pwt2tr2 = tmp_pwt2 if ( tmp_pwt2 >= 0.1 & tmp_pwt2 <= 0.9 );

sum tmp_pwt2tr1;
sum tmp_pwt2tr2;
by cid: egen pwt2tr1 = min(tmp_pwt2tr1); 
by cid: egen pwt2tr2 = min(tmp_pwt2tr2); 


* FLooded Quartile 3 estimating pscore;
dprobit t3 age age_sq age_cu 
        meanelev minelev maxelev
        meanelev_sq minelev_sq maxelev_sq
        meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        if qdate==yq(2005,2);

predict tmp_pwt3 if qdate==yq(2005,2) & (qdepth == 0 | qdepth == 3), pr;

* Min/Max trim;
* trim above control max;
sum tmp_pwt3 if qdepth == 0;
gen tmp_pwt3tr1 = tmp_pwt3 if tmp_pwt3 <= `r(max)';
* trim below treated min;
sum tmp_pwt3 if qdepth == 3;
replace tmp_pwt3tr1 = . if tmp_pwt3 <= `r(min)';

* 10/90 trim;
gen tmp_pwt3tr2 = tmp_pwt3 if ( tmp_pwt3 >= 0.1 & tmp_pwt3 <= 0.9 );

sum tmp_pwt3tr1;
sum tmp_pwt3tr2;
by cid: egen pwt3tr1 = min(tmp_pwt3tr1); 
by cid: egen pwt3tr2 = min(tmp_pwt3tr2); 


* FLooded Quartile 4 estimating pscore;
dprobit t4 age age_sq age_cu 
        meanelev minelev maxelev
        meanelev_sq minelev_sq maxelev_sq
        meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        if qdate==yq(2005,2);

predict tmp_pwt4 if qdate==yq(2005,2) & (qdepth == 0 | qdepth == 4), pr;

* Min/Max trim;
* trim above control max;
sum tmp_pwt4 if qdepth == 0;
gen tmp_pwt4tr1 = tmp_pwt4 if tmp_pwt4 <= `r(max)';
* trim below treated min;
sum tmp_pwt4 if qdepth == 4;
replace tmp_pwt4tr1 = . if tmp_pwt4 <= `r(min)';

* 10/90 trim;
gen tmp_pwt4tr2 = tmp_pwt4 if ( tmp_pwt4 >= 0.1 & tmp_pwt4 <= 0.9 );

sum tmp_pwt4tr1;
sum tmp_pwt4tr2;
by cid: egen pwt4tr1 = min(tmp_pwt4tr1); 
by cid: egen pwt4tr2 = min(tmp_pwt4tr2); 


* Create weights.  GIve treated weight of 1 and control pscore/(1-pscore);

gen invpwt1tr1 = pwt1tr1 / (1-pwt1tr1) if qdepth == 0;
replace invpwt1tr1 = 1 if qdepth == 1;
gen invpwt1tr2 = pwt1tr2 / (1-pwt1tr2) if qdepth == 0;
replace invpwt1tr2 = 1 if qdepth == 1;

gen invpwt2tr1 = pwt2tr1 / (1-pwt2tr1) if qdepth == 0;
replace invpwt2tr1 = 1 if qdepth == 2;
gen invpwt2tr2 = pwt2tr2 / (1-pwt2tr2) if qdepth == 0;
replace invpwt2tr2 = 1 if qdepth == 2;

gen invpwt3tr1 = pwt3tr1 / (1-pwt3tr1) if qdepth == 0;
replace invpwt3tr1 = 1 if qdepth == 3;
gen invpwt3tr2 = pwt3tr2 / (1-pwt3tr2) if qdepth == 0;
replace invpwt3tr2 = 1 if qdepth == 3;

gen invpwt4tr1 = pwt4tr1 / (1-pwt4tr1) if qdepth == 0;
replace invpwt4tr1 = 1 if qdepth == 4;
gen invpwt4tr2 = pwt4tr2 / (1-pwt4tr2) if qdepth == 0;
replace invpwt4tr2 = 1 if qdepth == 4;



sort cid qdate;

* count of people in flood depth regions in full sample;
count if cid~=cid[_n-1] & qdepth == 0 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;
count if cid~=cid[_n-1] & qdepth == 1 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;
count if cid~=cid[_n-1] & qdepth == 2 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;
count if cid~=cid[_n-1] & qdepth == 3 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;
count if cid~=cid[_n-1] & qdepth == 4 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


* count of people in flood depth regions in trimmed 10/90 sample;
count if cid~=cid[_n-1] & qdepth == 0 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt1tr2 ~= .;
count if cid~=cid[_n-1] & qdepth == 1 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt1tr2 ~= .;

count if cid~=cid[_n-1] & qdepth == 0 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt2tr2 ~= .;
count if cid~=cid[_n-1] & qdepth == 2 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt2tr2 ~= .;

count if cid~=cid[_n-1] & qdepth == 0 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt3tr2 ~= .;
count if cid~=cid[_n-1] & qdepth == 3 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt3tr2 ~= .;

count if cid~=cid[_n-1] & qdepth == 0 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt4tr2 ~= .;
count if cid~=cid[_n-1] & qdepth == 4 & pres_during_katrina == 1 & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt4tr2 ~= .;




* APpendix Table 8 - Column 1;
clear matrix;

* Replication of Table 3 column 1;

reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* RUn simple diff in diff regs;

* APpendix Table 8 - Column 2;

* FLooded Quartile 1;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt1tr2 ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* FLooded Quartile 2;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 2) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt2tr2 ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* FLooded Quartile 3;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 3) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt3tr2 ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* APpendix Table 8 - Column 3;

* FLooded Quartile 4;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . & invpwt4tr2 ~= .
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];




* 10/90 trim;

* APpendix Table 8 - Column 4;

* FLooded Quartile 1;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . [aw=invpwt1tr2]
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* FLooded Quartile 2;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 2) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . [aw=invpwt2tr2]
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* FLooded Quartile 3;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 3) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . [aw=invpwt3tr2]
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* APpendix Table 8 - Column 5;

* FLooded Quartile 4;
reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . [aw=invpwt4tr2]
	, robust cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];



* APpendix Table 8 - Column 6;

* FLooded Quartile 1;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p

	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
        [aw=invpwt1tr2]
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* FLooded Quartile 2;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p

	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 2) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
        [aw=invpwt2tr2]
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];



* FLooded Quartile 3;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p

	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 3) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
        [aw=invpwt3tr2]
	, robust cluster(block_str_2005q3) absorb(cid);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* APpendix Table 8 - Column 7;

* FLooded Quartile 4;
areg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p 
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p

	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .
        [aw=invpwt4tr2]
	, robust cluster(block_str_2005q3) absorb(cid);


matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];

* Appendix Table 8;
matrix list results;
clear matrix;

clear;





* Appendix Table 9;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


* QUantile regressions;
clear matrix;

* Replication of Table 3 column 4;

* TOtal debt;

reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(25);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(51);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(75);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


* Keep only people with mortgage at time of Katrina;
keep if had_mtg == 1;

* TOtal debt;

reg bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];



qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(25);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(50);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];


qreg2 bal_all_tot_imp
        floodedq1_x_p floodedq2_x_p floodedq3_x_p floodedq4_x_p
        floodedq1 floodedq2 floodedq3 floodedq4 
	post
        meanelev minelev maxelev meanelev_sq minelev_sq maxelev_sq meanelev_cu minelev_cu maxelev_cu 
	propa propa_sq propa_cu propa_x_elev 
	age age_sq age_cu 
	lmedoohval lmedhhinc foo faa fhisp f65p povrate fba
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= . 
	, cluster(block_str_2005q3) q(75);

matrix results_new = _b[floodedq1_x_p];
matrix results_new = [ results_new\ _se[floodedq1_x_p] ];
matrix results_new = [ results_new\ _b[floodedq2_x_p] ];
matrix results_new = [ results_new\ _se[floodedq2_x_p] ];
matrix results_new = [ results_new\ _b[floodedq3_x_p] ];
matrix results_new = [ results_new\ _se[floodedq3_x_p] ];
matrix results_new = [ results_new\ _b[floodedq4_x_p] ];
matrix results_new = [ results_new\ _se[floodedq4_x_p] ];

matrix results_new = [ results_new\ _b[floodedq1] ];
matrix results_new = [ results_new\ _se[floodedq1] ];
matrix results_new = [ results_new\ _b[floodedq2] ];
matrix results_new = [ results_new\ _se[floodedq2] ];
matrix results_new = [ results_new\ _b[floodedq3] ];
matrix results_new = [ results_new\ _se[floodedq3] ];
matrix results_new = [ results_new\ _b[floodedq4] ];
matrix results_new = [ results_new\ _se[floodedq4] ];

matrix results_new = [ results_new\ _b[post] ];
matrix results_new = [ results_new\ _se[post] ];

matrix results_new = [ results_new\ e(N) ];
matrix results_new = [ results_new\ e(r2) ];

matrix results = [nullmat(results), results_new];

* Appendix Table 9;
matrix list results;
clear matrix;


* Appendix Figure 3;

use ../tmp_data/parcel_level_data.dta, clear;

gen pct_chg_hist = 100 *  pct_chg;
label var pct_chg_hist "Change in Assessed Value (in Percentage Points)";
hist pct_chg_hist if pct_chg <= 0, scheme(s1mono) freq;
graph save ../figures/figure_appendix3.gph, replace;

clear;



* Appendix Figure 4, 5, 6, 11, 12;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if pres_during_katrina == 1 & qdepth~=. & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

* Bring in control cities;
append using ../tmp_data/frbnyccp_100pct_primary_cid_controlcities_ever_follow_imputed.dta;

replace qdepth = -3 if placenm == "Baton Rouge city";
replace qdepth = -2 if placenm == "Memphis city";
replace qdepth = -1 if placenm == "St. Louis city";

keep if qdate>=yq(2002,3) & qdate<=yq(2008,3) & (pres_during_katrina==1 | placenm~="") & fullsample0208==1 & num_all_tot ~= .;

drop gt1_home_tot_imp;
gen gt1_home_tot_imp = gt1_home_tot;
replace gt1_home_tot_imp = 1 if (nonreport>0 & nonreport~=.);

drop bal_home_tot_imp;
gen bal_home_tot_imp = bal_home_tot;
replace bal_home_tot_imp = bal_imp if (nonreport>0 & nonreport~=.);

drop bal_all_tot_imp;
gen bal_all_tot_imp = bal_all_tot - bal_home_tot + bal_home_tot_imp;

drop shrrpt;
gen shrrpt = 0;
replace shrrpt = 1 if (nonreport==0 | nonreport==.);
gen shrnorpt = 1 - shrrpt;

collapse (mean) gt1_home_tot gt1_bcret_tot gt1_auto_tot gt1_stdln_tot shrnorpt gt1_home_tot_imp, by(qdate qdepth);

label var qdate "Quarter of Year";
label var gt1_home_tot "Share with Home Loan";
label var gt1_bcret_tot "Share with Credit Card";
label var gt1_auto_tot "Share with Auto Loan";
label var gt1_stdln_tot "Share with Student Loan";
label var shrnorpt "Share with Non-Reporting of a Home Loan";
label var gt1_home_tot_imp "Share with Home Loan (imputed)";

foreach v in shrnorpt gt1_home_tot gt1_home_tot_imp gt1_auto_tot gt1_bcret_tot {;
  twoway (connected `v' qdate if qdepth==0, lcolor(blue) msymbol(X) mcolor(blue)) 
  	 (connected `v' qdate if qdepth==1, lcolor(green) msymbol(S) mcolor(green)) 
	 (connected `v' qdate if qdepth==2, lcolor(orange) msymbol(Dh) mcolor(orange)) 
	 (connected `v' qdate if qdepth==3, lcolor(sienna) msymbol(Th) mcolor(sienna)) 
	 (connected `v' qdate if qdepth==4, lcolor(red) msymbol(O) mcolor(red))
	 (connected `v' qdate if qdepth==-2, lcolor(purple) msymbol(Sh) mcolor(purple))
	 (connected `v' qdate if qdepth==-1, lcolor(teal) msymbol(Oh) mcolor(teal))

	 , legend( label(1 "Not Flooded") label(2 "Flood Quartile 1") label(3 "Flood Quartile 2") label(4 "Flood Quartile 3") label(5 "Flood Quartile 4") label(6 "Memphis") label(7 "St. Louis") )
	 xline(182, lcolor(black)) xlabel(172(4)192) xmtick(170(1)194)
         scheme(s2mono) plotregion(fcolor(white)) graphregion(fcolor(white));
  graph save ../figures/figure_appendix4_5_6_11_12_`v'.gph, replace;
};



* Appendix Figures 7, 8, 9, 10;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if pres_during_katrina == 1 & qdepth~=. & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

keep if qdate>=yq(2002,3) & qdate<=yq(2008,3) & pres_during_katrina==1 & fullsample0208==1;

collapse (mean) bal_home_tot bal_home_tot_imp_prev bal_home_tot_imp_next bal_home_tot_imp, by(qdate qdepth);

label var qdate "Quarter of Year";
label var bal_home_tot "Home Loan Balance";
label var bal_home_tot_imp "Home Loan Balance (imputed-linear)";
label var bal_home_tot_imp_prev "Home Loan Balance (imputed-ub)";
label var bal_home_tot_imp_next "Home Loan Balance (imputed-lb)";

foreach v in bal_home_tot bal_home_tot_imp_prev bal_home_tot_imp_next bal_home_tot_imp {;
  twoway (connected `v' qdate if qdepth==0, lcolor(blue) msymbol(X) mcolor(blue)) 
  	 (connected `v' qdate if qdepth==1, lcolor(green) msymbol(S) mcolor(green)) 
	 (connected `v' qdate if qdepth==2, lcolor(orange) msymbol(Dh) mcolor(orange)) 
	 (connected `v' qdate if qdepth==3, lcolor(sienna) msymbol(Th) mcolor(sienna)) 
	 (connected `v' qdate if qdepth==4, lcolor(red) msymbol(O) mcolor(red))
	 , legend( label(1 "Not Flooded") label(2 "Flood Quartile 1") label(3 "Flood Quartile 2") label(4 "Flood Quartile 3") label(5 "Flood Quartile 4") )  
	 xline(182, lcolor(black)) xlabel(172(4)192) xmtick(170(1)194)
         scheme(s2mono) plotregion(fcolor(white)) graphregion(fcolor(white));
  graph save ../figures/figure_appendix7-10_`v'.gph, replace;
};


* Appendix Figure 13;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

areg bal_auto_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Balance of Auto Loans (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));

graph save ../figures/figure_appendix13.gph, replace;



* Create student loan event study figure;
    
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

areg bal_stdln_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Balance of Student Loans (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));

graph save ../figures/figure_studentloan.gph, replace;




* Appendix Figure 14;

use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if pres_during_katrina == 1 & qdepth~=. & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;

* Below Median credit score mentioned in Text of the Paper;
areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & belowmedrs == 1
	, robust cluster(block_str_2005q3) absorb(cid);

* For Completeness do below and above 25th and 75th percentile credit score;
areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & below25prs == 1
	, robust cluster(block_str_2005q3) absorb(cid);

areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & below25prs == 0
	, robust cluster(block_str_2005q3) absorb(cid);

areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & below75prs == 1
	, robust cluster(block_str_2005q3) absorb(cid);

areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & below75prs == 0
	, robust cluster(block_str_2005q3) absorb(cid);


* Above median credit score used in appendix figure;

areg bal_bcret_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= . & belowmedrs == 0
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Credit Card Balance (Dollars)") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black))  ;

graph save ../figures/figure_appendix14.gph, replace;



* Appendix Figure 15, 17; 

* Migration: need to keep people who moved away before Katrina;
use ../tmp_data/frbnyccp_100pct_primary_cid_flooddepth_algiers_ever_follow_for_analysis_no_controlcities.dta, clear;

keep if (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & age ~=. & lmedoohval ~= . & num_all_tot ~= .;


foreach v in leftcsageq3yr leftcsageq1yr {;

	disp "`v'";

	areg `v'

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Share that Left the New Orleans CSA") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));


graph save ../figures/figure_appendix15and17_`v'.gph, replace;


};


* Appendix Figure 16;

	areg leftgeq3yr

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3))
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Share that Left the City of New Orleans") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));


graph save ../figures/figure_appendix16.gph, replace;


* Appendix Figure 18;

areg gt1_home_tot_imp_had_mtg

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

	age age_sq age_cu
        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (pres_during_katrina == 1 ) & (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & fullsample0208==1 & (qdate>=yq(2002,3) & qdate<=yq(2008,3)) & num_all_tot ~= .
	, robust cluster(block_str_2005q3) absorb(cid);

	plottscoeffskatrina12qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 


, ytitle("Share with a Home Loan") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));

graph save ../figures/figure_appendix18.gph, replace;



* Appendix Figure 19;

* Use block depth file;
use ../tmp_data/nola_w_algiers_flood_risk_katrina_depth.dta, clear;

merge 1:m block_str using ../tmp_data/home_sales_by_block_quarter.dta;

collapse (sum) trans (sum) price, by(qdepth qdate);

table qdate qdepth, c(mean trans mean price);

format qdate %tq;

twoway (connected trans qdate if qdepth == 0, lcolor(blue) msymbol(X) mcolor(blue)) (connected trans qdate if qdepth == 1, lcolor(green) msymbol(S) mcolor(green)) (connected trans qdate if qdepth == 4, lcolor(red) msymbol(O) mcolor(red)) if qdate>= yq(2002,3) & qdate <= yq(2008,3), ytitle("Home Sales") xline(182, lcolor(black)) xlabel(172(4)192) xmtick(170(1)194) legend(label( 1 "Not Flooded") label(2 "Least Flooded Quartile") label(3 "Most Flooded Quartile")) xtitle("Quarter of Year")
scheme(s2mono) plotregion(fcolor(white)) graphregion(fcolor(white));

graph save ../figures/figure_appendix19.gph, replace;
clear;







* analyze changes in owner occupancy rates;

use ../raw_data/frbnyccp_100pct_flooddepth014_follow_present.dta, clear;
// merge in state FIPS codes;

sort cid;
merge m:1 cid using ../tmp_data/q014_cid_qdepth_mtg.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

gen qdate = yq(year(qtr), quarter(qtr));
format qdate %tq;
drop qtr;

sort state;
merge m:1 state using ../raw_data/state_fips.dta;
tab _merge;
keep if _merge == 3;
drop _merge;

gen block2000 = string(state_code, "%02.0f") + county_code + census_tract + census_block;

gen block2010 = string(state_code, "%02.0f") + county_code_2010 + census_tract_2010 + census_block_2010;

sort block2000;

merge m:1 block2000 using ../raw_data/block2000_hu_us.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

drop fwa002 fwc*;
replace fv5001 = . if qdate~=yq(2005,2);
replace fv8001 = . if qdate~=yq(2005,2);
replace fv8002 = . if qdate~=yq(2005,2);
replace fwa001 = . if qdate~=yq(2005,2);

gen foo_block2000 = fwa001 / fv8001;
gen fvac_block2000 = fv8002 / fv5001;

drop fv5001 fv8001 fv8002 fwa001;


sort block2010;

merge m:1 block2010 using ../raw_data/block2010_hu_us.dta;
tab _merge;
drop if _merge == 2;
drop _merge;

drop iff004 ifg*;
replace ifc001 = . if qdate~=yq(2014,2);
replace ife002 = . if qdate~=yq(2014,2);
replace ife003 = . if qdate~=yq(2014,2);
replace iff002 = . if qdate~=yq(2014,2);
replace iff003 = . if qdate~=yq(2014,2);

gen foo_block2010 = (iff002 + iff003) / ife002;
gen fvac_block2010 = ife003 / ifc001;
gen fmtg_block2010 = iff002 / (iff002 + iff003);

drop ifc001 ife002 ife003 iff002 iff003;


sum foo_block2000 if qdepth==0 & had_mtg == 1, d;
sum foo_block2010 if qdepth==0 & had_mtg == 1, d;

sum foo_block2000 if qdepth==1 & had_mtg == 1, d;
sum foo_block2010 if qdepth==1 & had_mtg == 1, d;

sum foo_block2000 if qdepth==4 & had_mtg == 1, d;
sum foo_block2010 if qdepth==4 & had_mtg == 1, d;


* want to add the imputation from the tradeline data here;
sort cid qdate;
merge 1:1 cid qdate using ../tmp_data/mortgage_tl_depthcoverage_ever_imputedbals.dta;
drop if _merge == 2;
gen mtg_exists = (_merge == 3);
drop _merge;

rename crtr_attr1 num_all_tot;
rename crtr_attr6 num_fmrtg_tot;
rename crtr_attr7 num_helin_tot;
rename crtr_attr8 num_helre_tot;
gen num_home_tot = num_fmrtg_tot + num_helin_tot + num_helre_tot;

gen gt1_home_tot = 0 if num_home_tot ~= .;
replace gt1_home_tot = 1 if num_home_tot > 0 & num_home_tot ~= .;

gen gt1_home_tot_imp = gt1_home_tot;
replace gt1_home_tot_imp = 1 if (nonreport>0 & nonreport~=.) & num_all_tot ~=. ;



keep if had_mtg == 1;

collapse (mean) gt1_home_tot_imp, by(qdate qdepth);

reshape wide gt1_home_tot_imp, i(qdate) j(qdepth);

tsset qdate;
format qdate %tq;

twoway (tsline gt1_home_tot_imp0) (tsline gt1_home_tot_imp1) (tsline gt1_home_tot_imp4);
graph save ../figures/homeownership_persistence.gph, replace;
graph export ../figures/homeownership_persistence.pdf, replace;

clear;



use ../tmp_data/block_level_ccp_pop_num_home_loan.dta, clear;

replace obs = 20 * obs;
sum obs if qdate==yq(2005,2) & qdepth == 0;
sum obs if qdate==yq(2005,2) & qdepth == 1;
sum obs if qdate==yq(2005,2) & qdepth == 4;

replace gt1_home_tot = 20 * gt1_home_tot;
sum gt1_home_tot if qdate==yq(2005,2) & qdepth == 0;
sum gt1_home_tot if qdate==yq(2005,2) & qdepth == 1;
sum gt1_home_tot if qdate==yq(2005,2) & qdepth == 4;

sum gt1_home_tot if qdate==yq(2007,1) & qdepth == 0;
sum gt1_home_tot if qdate==yq(2007,1) & qdepth == 1;
sum gt1_home_tot if qdate==yq(2007,1) & qdepth == 4;



areg gt1_home_tot

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq1_x_2008q4
floodedq1_x_2009q1 floodedq1_x_2009q2 floodedq1_x_2009q3 floodedq1_x_2009q4
floodedq1_x_2010q1 floodedq1_x_2010q2 floodedq1_x_2010q3 floodedq1_x_2010q4
floodedq1_x_2011q1 floodedq1_x_2011q2 floodedq1_x_2011q3 floodedq1_x_2011q4
floodedq1_x_2012q1 floodedq1_x_2012q2 floodedq1_x_2012q3 floodedq1_x_2012q4
floodedq1_x_2013q1 floodedq1_x_2013q2 floodedq1_x_2013q3 floodedq1_x_2013q4
floodedq1_x_2014q1 floodedq1_x_2014q2 floodedq1_x_2014q3 floodedq1_x_2014q4
floodedq1_x_2015q1 floodedq1_x_2015q2 floodedq1_x_2015q3 

floodedq2_x_2002q3 floodedq2_x_2002q4 floodedq2_x_2003q1 floodedq2_x_2003q2 floodedq2_x_2003q3 floodedq2_x_2003q4 floodedq2_x_2004q1 floodedq2_x_2004q2 floodedq2_x_2004q3 floodedq2_x_2004q4 floodedq2_x_2005q1 floodedq2_x_2005q3 floodedq2_x_2005q4 floodedq2_x_2006q1 floodedq2_x_2006q2 floodedq2_x_2006q3 floodedq2_x_2006q4 floodedq2_x_2007q1 floodedq2_x_2007q2 floodedq2_x_2007q3 floodedq2_x_2007q4 floodedq2_x_2008q1 floodedq2_x_2008q2 floodedq2_x_2008q3

floodedq2_x_2008q4
floodedq2_x_2009q1 floodedq2_x_2009q2 floodedq2_x_2009q3 floodedq2_x_2009q4
floodedq2_x_2010q1 floodedq2_x_2010q2 floodedq2_x_2010q3 floodedq2_x_2010q4
floodedq2_x_2011q1 floodedq2_x_2011q2 floodedq2_x_2011q3 floodedq2_x_2011q4
floodedq2_x_2012q1 floodedq2_x_2012q2 floodedq2_x_2012q3 floodedq2_x_2012q4
floodedq2_x_2013q1 floodedq2_x_2013q2 floodedq2_x_2013q3 floodedq2_x_2013q4
floodedq2_x_2014q1 floodedq2_x_2014q2 floodedq2_x_2014q3 floodedq2_x_2014q4
floodedq2_x_2015q1 floodedq2_x_2015q2 floodedq2_x_2015q3 

floodedq3_x_2002q3 floodedq3_x_2002q4 floodedq3_x_2003q1 floodedq3_x_2003q2 floodedq3_x_2003q3 floodedq3_x_2003q4 floodedq3_x_2004q1 floodedq3_x_2004q2 floodedq3_x_2004q3 floodedq3_x_2004q4 floodedq3_x_2005q1 floodedq3_x_2005q3 floodedq3_x_2005q4 floodedq3_x_2006q1 floodedq3_x_2006q2 floodedq3_x_2006q3 floodedq3_x_2006q4 floodedq3_x_2007q1 floodedq3_x_2007q2 floodedq3_x_2007q3 floodedq3_x_2007q4 floodedq3_x_2008q1 floodedq3_x_2008q2 floodedq3_x_2008q3

floodedq3_x_2008q4
floodedq3_x_2009q1 floodedq3_x_2009q2 floodedq3_x_2009q3 floodedq3_x_2009q4
floodedq3_x_2010q1 floodedq3_x_2010q2 floodedq3_x_2010q3 floodedq3_x_2010q4
floodedq3_x_2011q1 floodedq3_x_2011q2 floodedq3_x_2011q3 floodedq3_x_2011q4
floodedq3_x_2012q1 floodedq3_x_2012q2 floodedq3_x_2012q3 floodedq3_x_2012q4
floodedq3_x_2013q1 floodedq3_x_2013q2 floodedq3_x_2013q3 floodedq3_x_2013q4
floodedq3_x_2014q1 floodedq3_x_2014q2 floodedq3_x_2014q3 floodedq3_x_2014q4
floodedq3_x_2015q1 floodedq3_x_2015q2 floodedq3_x_2015q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 

floodedq4_x_2008q4
floodedq4_x_2009q1 floodedq4_x_2009q2 floodedq4_x_2009q3 floodedq4_x_2009q4
floodedq4_x_2010q1 floodedq4_x_2010q2 floodedq4_x_2010q3 floodedq4_x_2010q4
floodedq4_x_2011q1 floodedq4_x_2011q2 floodedq4_x_2011q3 floodedq4_x_2011q4
floodedq4_x_2012q1 floodedq4_x_2012q2 floodedq4_x_2012q3 floodedq4_x_2012q4
floodedq4_x_2013q1 floodedq4_x_2013q2 floodedq4_x_2013q3 floodedq4_x_2013q4
floodedq4_x_2014q1 floodedq4_x_2014q2 floodedq4_x_2014q3 floodedq4_x_2014q4
floodedq4_x_2015q1 floodedq4_x_2015q2 floodedq4_x_2015q3 


d2002q3 d2002q4 
d2003q1 d2003q2 d2003q3 d2003q4 
d2004q1 d2004q2 d2004q3 d2004q4 
d2005q1 d2005q3 d2005q4 
d2006q1 d2006q2 d2006q3 d2006q4 
d2007q1 d2007q2 d2007q3 d2007q4 
d2008q1 d2008q2 d2008q3 

d2008q4
d2009q1 d2009q2 d2009q3 d2009q4 
d2010q1 d2010q2 d2010q3 d2010q4 
d2011q1 d2011q2 d2011q3 d2011q4 
d2012q1 d2012q2 d2012q3 d2012q4 
d2013q1 d2013q2 d2013q3 d2013q4 
d2014q1 d2014q2 d2014q3 d2014q4 
d2015q1 d2015q2 d2015q3 

        meanelev_p minelev_p maxelev_p meanelev_sq_p minelev_sq_p maxelev_sq_p meanelev_cu_p minelev_cu_p maxelev_cu_p 
	propa_p propa_sq_p propa_cu_p propa_x_elev_p 
	lmedoohval_p lmedhhinc_p foo_p faa_p fhisp_p f65p_p povrate_p fba_p
	if ( (qdepth == 0 | qdepth == 1 | qdepth == 2 | qdepth == 3 | qdepth == 4) ) & (qdate>=yq(2002,3) & qdate<=yq(2015,3))
	, robust absorb(block_str);



	plottscoeffskatrina40qaxes 

floodedq1_x_2002q3 floodedq1_x_2002q4 floodedq1_x_2003q1 floodedq1_x_2003q2 floodedq1_x_2003q3 floodedq1_x_2003q4 floodedq1_x_2004q1 floodedq1_x_2004q2 floodedq1_x_2004q3 floodedq1_x_2004q4 floodedq1_x_2005q1 floodedq1_x_2005q1 floodedq1_x_2005q3 floodedq1_x_2005q4 floodedq1_x_2006q1 floodedq1_x_2006q2 floodedq1_x_2006q3 floodedq1_x_2006q4 floodedq1_x_2007q1 floodedq1_x_2007q2 floodedq1_x_2007q3 floodedq1_x_2007q4 floodedq1_x_2008q1 floodedq1_x_2008q2 floodedq1_x_2008q3

floodedq1_x_2008q4
floodedq1_x_2009q1 floodedq1_x_2009q2 floodedq1_x_2009q3 floodedq1_x_2009q4
floodedq1_x_2010q1 floodedq1_x_2010q2 floodedq1_x_2010q3 floodedq1_x_2010q4
floodedq1_x_2011q1 floodedq1_x_2011q2 floodedq1_x_2011q3 floodedq1_x_2011q4
floodedq1_x_2012q1 floodedq1_x_2012q2 floodedq1_x_2012q3 floodedq1_x_2012q4
floodedq1_x_2013q1 floodedq1_x_2013q2 floodedq1_x_2013q3 floodedq1_x_2013q4
floodedq1_x_2014q1 floodedq1_x_2014q2 floodedq1_x_2014q3 floodedq1_x_2014q4
floodedq1_x_2015q1 floodedq1_x_2015q2 floodedq1_x_2015q3 

floodedq4_x_2002q3 floodedq4_x_2002q4 floodedq4_x_2003q1 floodedq4_x_2003q2 floodedq4_x_2003q3 floodedq4_x_2003q4 floodedq4_x_2004q1 floodedq4_x_2004q2 floodedq4_x_2004q3 floodedq4_x_2004q4 floodedq4_x_2005q1 floodedq1_x_2005q1 floodedq4_x_2005q3 floodedq4_x_2005q4 floodedq4_x_2006q1 floodedq4_x_2006q2 floodedq4_x_2006q3 floodedq4_x_2006q4 floodedq4_x_2007q1 floodedq4_x_2007q2 floodedq4_x_2007q3 floodedq4_x_2007q4 floodedq4_x_2008q1 floodedq4_x_2008q2 floodedq4_x_2008q3 
floodedq4_x_2008q4
floodedq4_x_2009q1 floodedq4_x_2009q2 floodedq4_x_2009q3 floodedq4_x_2009q4
floodedq4_x_2010q1 floodedq4_x_2010q2 floodedq4_x_2010q3 floodedq4_x_2010q4
floodedq4_x_2011q1 floodedq4_x_2011q2 floodedq4_x_2011q3 floodedq4_x_2011q4
floodedq4_x_2012q1 floodedq4_x_2012q2 floodedq4_x_2012q3 floodedq4_x_2012q4
floodedq4_x_2013q1 floodedq4_x_2013q2 floodedq4_x_2013q3 floodedq4_x_2013q4
floodedq4_x_2014q1 floodedq4_x_2014q2 floodedq4_x_2014q3 floodedq4_x_2014q4
floodedq4_x_2015q1 floodedq4_x_2015q2 floodedq4_x_2015q3 



, ytitle("Number of People per Block with a Home Loan") xtitle("Quarter of Year") xstart(2002.5) xincr(0.25) yline(0, lcolor(black)) xline(2005.5, lcolor(black));


graph save ../figures/figure_appendix20.gph, replace;



log close;
